/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvMath.h"
#include "HvControlIf.h"
#include "HvControlTabhead.h"
#include "HvControlUnop.h"
#include "HvControlSystem.h"
#include "HvSignalPhasor.h"
#include "HvControlRandom.h"
#include "HvControlPack.h"
#include "HvSignalRPole.h"
#include "HvControlVar.h"
#include "HvControlCast.h"
#include "HvSignalVar.h"
#include "HvSignalLine.h"
#include "HvSignalTabread.h"
#include "HvSignalTabwrite.h"
#include "HvSignalDel1.h"
#include "HvControlSlice.h"
#include "HvTable.h"
#include "HvControlBinop.h"
#include "HvControlDelay.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_FHnZSmmu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AYuAIczb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_fEByXeW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3qkakvLL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pp0ULDWs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f64ZcYqi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_Hp3dPUlN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6aLfVu2s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bbHhUxtj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MJih7RnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AaxoYNxX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oXg7lhAa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4qCmrLf2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_v8aPBuEN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ubTKsrXV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_gXBDIrkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GRJQNsD8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_710ZaHUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7cyRms36_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4hLc26fi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U9U1IhgP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uXUeCVcR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jSokIxI5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2N6rXgLb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZF0YUKC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KSEPOaG8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h7fkhoct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2wrLH1nt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fNkP40Mt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rGaCA7pz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kPAEImOq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zJAhhKy7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PE7Lo9TC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mFknCUJP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gjrsjdfG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ruPIZ8Jx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8CQtU8SF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2uSbcd42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_necttOGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K94Jrdb3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fcXaFhCI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6VyR4WTW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IJpJCaCG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iV9UAcTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oP4NcYf0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_vik8tVeL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_q0FVTB1S_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_0EpOW7Dp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DEKMxhfz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U7JBwdiz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lyQ9JNLD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WkPhcxYZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rmuZI1ZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rr2AqyTF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CCVccWdU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fmATEhwo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vJZrsRn4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3WVsk0t1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rxbUGsI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ymra7Aaa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l3OEoTOh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bvn5vENf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nNVuuYRN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SDPBmrwp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_vmQ29VkO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_S7poB7Qs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_HmIjCB38_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_WgY0um3S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0U82drI4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_FZcxPqHl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mNPr7Il6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LP5M2Wvr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vqxii9Bk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tKrI5wgy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ACZgaO8r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oAiAeOPS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UwxHwPJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4EQO4NJd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Wnh3RMT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I79T9ylW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_36xnQg8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GEcAhmZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VpL9vr7S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MoLqPK5W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Rh6a9PBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Msyhrw2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zWe1jbEY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vtLQcGWq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_g17VCosP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SF6ZhLYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N2RnpxVE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hCTW0WZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fkBzNIhI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jAjqo2Xr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pgk2oe3x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PxERa694_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f2JtkpSa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_CiaBiVUx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NWDNlvmu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LrjqdN8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AbUv6Rxa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CjiAqkWJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VS2UJmMd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_gwZ9hqgs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AbCmk3fb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ufhviyas_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3h0YZRPY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ovicBIU4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NceNdnju_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AhdkYPAX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pOwbymw4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ri7s1YLQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AnKttOcl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wqw0VOEm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MYNXNCbX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W1OcCjIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_ZspbjrXY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jo6SmE9X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RJ8ZYwS1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Zf3XSh8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_lcox6wgb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sXvHxIO8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ZltNwp5A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nzHuNjWI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9iYcvpRX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1rDlXTZZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xbmDQcaS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LgKiizjO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BT5Kry0L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RHf8NP5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SpzAx2FK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8Q2Z1OgR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yyils2n0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EE7tJCQi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fUkk7lR0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_PZS2RrJp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A7w72u7b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0L9lskoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sY1p39Y5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TTkKbmBY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_w9tOUnI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_DuDoObTu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xzN6iPUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZBzLs6ln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qtZAhhcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0TbPoHYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6xic4mpd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0rGpzGcD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vU76c0BS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZBTQ9mpZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lyGEeHZS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pa8DYYCT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PneCyMRH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xL4EfCUu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6d3ZrZFE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4Bo6NYsE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nFsfUD5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dZsx4GYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TV2vvmyJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_5phpijmG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_G51eVCsN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nJuILwB8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ON7wBkiA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YN1pWldm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pEyBKuUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h1CcruBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pZE3mbBn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mRpRHhWP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_iTcSiq48_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MZsDU3dQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xdyVCdR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4OtOTJ8D_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_WuiRx2vW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_G2YPXHz2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UEpkr8Ih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H4angjxJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mvQX2J91_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2yVtVknV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ygi9rJ84_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4JpHNtQ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NK27DJdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FsPe6vkY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_foZstvs7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_A0JBLtZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wesIENsN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_x79MWxft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_fUthjX2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sNseJstW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dLUGf1VO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i1973J8u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q53wQgBb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_agWThiKY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BZbaocDv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DDCxZUpa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Oq2JYx7e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_fSeJnMu5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_u5R27CFI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YA27dO6m_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_gJfqSoTE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_zWrps4fR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B6h9DG3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_clFyXaPG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZzDjFtNE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F5ltni6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zcwghlIB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yYw9eTa1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_3PxPpXda_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_3TK88cro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_negIeu0B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QUvXvldK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Zm8WJwS1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F9sXnCIv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qjw0qzwc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eCuJr5cc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y6MBQwia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8mYPdYyy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qY5qGXkV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CFdGFFmk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Yj5DxO7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JASygFtc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kjlaU7dR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_E5GVivOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gxFiLM5W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_s6H3yt3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0BrMQM3S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_am8TrKoZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7BkNrUiZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ItU380X9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KW3kZjL9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_IQxw8B1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_eaufajib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aIqeqSOo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_HkqfqTjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_cH10QC8y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2pplyCnX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XjWvGHcB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eDviefti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MU1Ba0HD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qSBxmppU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wlwH7ecd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Y0REFUsa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yMuuykJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_s1YHWc4f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_W8TUcyVA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_osI1UkhA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zhvWcdyM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_PNZNngt8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GhV1AHG8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SolGE8k9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qIdSZtaw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZXiWotnN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sRZSFEZm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QvuklLqQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hAYm6QZv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JpC6CR20_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ndr9obp7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SAt5WDba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rSbPKypg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F3BP3afM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7d6qzdSf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tlpaSdB4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_G1KZYr4w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kPghd8IX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_eH8aknWv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_JH71u3co_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Roo2Fcq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IeKmhonz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OgSjAfgc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dNRRvYKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8NkHWBuC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v9hUuOK8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_95DWPg47_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_VH7M8GlM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_voTo4a3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PpyDSycw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WY62FWJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_YEFQDZNF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_whp40bST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_sWPP1lIe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e3qKJglz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_js3JqqMw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CbSFuQkU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fHlD2hPl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6AFsTkDK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yCDYS6jg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fqwDgtwq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1by74htG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q8lFqXGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BLtSX5Nt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_83viiklP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mmyyH3T4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s8yrEN62_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hrjHhpXn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_EOSEFU7P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TsIae3iL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KYHiukOX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_V1KEHKdX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_0CwqDI62_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bR26T3Hc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_loSCSMG7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A1o5GbAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p3xfcfkK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2QqFCrGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n6RyzBJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_vhAZxxiF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GWNibYnU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_w9I5Ze8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Sxa856Vc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JHgqyc4t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DE7IjjYx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_pzk8qRlU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5ftnPcjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iWVu5jcI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2IH3VvMQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_C0QIfWSU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O8kxrxOA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KLhE4gnR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JFYtORSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DCmFQgMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SKX5sXEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_adVqBGys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mTRqwPe8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K6u7jCXH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ab8uhK3V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Ivq0vNYV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_V1quRLLa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_avV5j0eB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lcagQ5RP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_hncopPsf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_ZA2moZ9n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6Jf8awa6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3w4f86NM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vXD2faP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VN5J0oGd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZVnB1vY1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gm3gQDfX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_ZdFbYQZi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d9fMw8wT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XDwPBenr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dwx7zDra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CwYxkmuL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sVmIeNmm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_rWbJFMc4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8ZvCB7qw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cMybJsOI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hlEyloRV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hTGSm3rr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NoSHdNMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3qOE0HT7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8V0ignQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k0hDJo0H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eP7rMKes_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nRh6PX8l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y38zgqIZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z1kLZGdS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UmDry9uh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mK7OV9M7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_mXSNy8NC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qQQi5lkX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_otO7fVR6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_0P1zyKOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Wpgscf8e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rba8nAIU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z9SpKXFT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8XxuQKU7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k8oi2SiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2pjObLdO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ws6gNb6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_M4YvjE3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AXlbHOr3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wdXaMl4N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2gM0L0Cs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_f5OaB0aY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ILNVgBHr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_zoLt6y3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IO5iS2JY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FmMr1Dii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qb7dKf6X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cFCebtuT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fWmP14Jv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4KHH54DH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BxjrSbq4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j6GwZox3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7U4STJd0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nqfn0pkh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vlFvqLxG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OfpFLva9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fPMV6PNp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cdzLBLRn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_vZLKQigP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_1Jv9dk5d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4uWynnl7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ey6aBt9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Bc18DgJK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tsccW4Y4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pPmHePrI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jIvMNwSa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8rrjLBRy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CXm5FGul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LpRVvNGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_WbDquKYi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wOyDJpRu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YFluwahw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GYrx9IoJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_cR1RgjDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_C1nYfjfg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_d8CU25Ny_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YvA25P6i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DGtRWWqS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xrFIWWTX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_iGE9HuBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XgtJStKp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rrxp88Tr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pnOwFltG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PCVv96wW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y49R5OpP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZkxZMtCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_27cGLCE9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h4kWsSiW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_k4vFkX7E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_m4BmPXGq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_Poz53EhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cdfSlOpK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JUQLQxgj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_it4357Rr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vztiuzLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mtc3YiXw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5O79CuXt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_15ZXbyQ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dv6nL3PM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iRpF2klt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qmmf0Boh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FxHOlo3R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GH3D0VzP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_COhrcvnM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oDb0w1jv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NSQlhOGR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UxDkckJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pl7QlUfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kYQUuT4u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bpThspCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SU99FHmz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sZpjcCUV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0shQaeDW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7992qohC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yAdQeHSF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JMz3Syoh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X0XjQ9th_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZHbKVSxc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dnIYyjab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c46fFnHc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_45FCAoQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MjrkzQ1c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bocuAlTD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ARWqrtDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vgZTOhCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_seDUrwRI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_86p0GWEh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3rzTJMvg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WD6pav80_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M42j0Uuj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z5982rr0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ltez59AZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PNUL1msZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yfdCz70C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Fv7tpn9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Q2qd14qz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jDrqFIZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hBcwOdTO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uf40F9OZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cPMa4fEw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LSiPOQYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bu3PgdsA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iOfDcm3w_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_UGgEybp1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_w7EEXtTy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GKEgXNFp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VLTsJLVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_81v13wKF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EdgIiOUd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OQpzai7T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3HD57pF8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Iouf9YOs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WhLNZf5m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XzH6KMiU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LnmFpeLp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pOOv638Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JnKXK1Ox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_nmBl8hTx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9o3MTh3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PgRhJGoL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qjAY3Fhg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zOK90yIr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W3pCGHgC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tcZLNEAg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eRAum5oo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wBGPwcwI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_23SMl5FA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mh5FVbzs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AckfzlxZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sWuVu59m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_z5XIlR94_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_AZJPcCCi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1OrY7Jw7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2VunGRv1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_r1lm8Sk6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Vu7hOJp8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JEk4GWQd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OApjwMR5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ElL8J4QU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8Uyaaiu9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_fgN5hOoi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_CiOR3X4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_iM2gjP27_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r4DmOdAo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NrtNfVkp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_PZywcTOe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_oj15Xjzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KI19z3ay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bYg3wIxj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kD9QzyPr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Z4pddmu2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_zMDUu8l5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HPREgDVc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8KSwcUFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SOhtdIlj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J2N9iQX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nv31PhhK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g0AtnHvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tu6lz3wI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ozcZi3WJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5GKHX0Dh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BkU321J5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JDFAwEG3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uC79O2e5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nPj72o0W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EUpHWQzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KlS64hBH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1Eu539Ec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5c88MSlC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XxgqZNMw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AgCcjMwR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jkdJjAjM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O2A17UeU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VXOjUwu6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jt11on4f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ov6eoI1k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E4IR9DRZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hfwlkKMT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wEZsbeAk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R6hXBp3a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vLgW4MmD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pdEH01NG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_owG3A0Lm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n1VAK7gC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nfDQv3y4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C3zuiNu7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Bw2LUh2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mLlzFGAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MsKcz4LP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UsE3tkM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K1txig4u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R100i84R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_smHOyqhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Vrzn9hHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9lnwzXw9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ui8EvQZx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eH07MxtC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_obtxSedD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tvZTJwSO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_e7kSqYue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_se1CfxxZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FjQD1Zed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zaddWvZZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q0Wfoagc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t8ohoFq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lrcztyX0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X9WBnvYP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xFhmlisr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UibFka17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m2mHjNTe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JAlARGNp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MVl0p7Qh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0Camk34R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7GP9dzfb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JiQS9hV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iisfWxL4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_im3mCUiX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pp8qtJxi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dF9KIZPE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_83AOxpgt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LMH1cg84_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xXGKSEzE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jMzPCS1M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZuUSAuIt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_J9zWq8Hk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eO17iq8i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dildUuMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1DBY1Qxk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_v6CQdCe7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QkW9AqnJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QaVRAQGE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LsbYlL3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pbGbXpte_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TyP9iHWP_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_z2Fj9mVh;
  SignalLine sLine_RfoYL2qg;
  SignalLine sLine_DklJ5SDZ;
  SignalTabhead sTabhead_LHbrNcNF;
  SignalTabread sTabread_2ytGmiKh;
  SignalTabread sTabread_Irf27Rto;
  SignalTabhead sTabhead_GpO4jdGa;
  SignalTabread sTabread_w0yStSGH;
  SignalTabread sTabread_G7u18Yvp;
  SignalTabwrite sTabwrite_J5ScRWwu;
  SignalRPole sRPole_P7VLnXF8;
  SignalDel1 sDel1_ufL71xut;
  SignalTabread sTabread_nmBl8hTx;
  SignalTabwrite sTabwrite_ILW0xCKI;
  SignalTabread sTabread_Rh6a9PBr;
  SignalRPole sRPole_Xle4sjh6;
  SignalLine sLine_8I3Zin3n;
  SignalLine sLine_W3z52TUg;
  SignalTabread sTabread_PNZNngt8;
  SignalTabread sTabread_sWPP1lIe;
  SignalTabread sTabread_pzk8qRlU;
  SignalTabread sTabread_rWbJFMc4;
  SignalTabread sTabread_d8CU25Ny;
  SignalTabread sTabread_zoLt6y3U;
  SignalTabwrite sTabwrite_tgbzZvny;
  SignalTabwrite sTabwrite_0s86JQUP;
  SignalTabwrite sTabwrite_u1ItxPrc;
  SignalTabwrite sTabwrite_YANjEak7;
  SignalTabwrite sTabwrite_6S4DHi75;
  SignalTabwrite sTabwrite_70INXAA6;
  SignalTabread sTabread_gwZ9hqgs;
  SignalRPole sRPole_5voas3A2;
  SignalTabread sTabread_ZltNwp5A;
  SignalRPole sRPole_ivYiGl13;
  SignalTabread sTabread_DuDoObTu;
  SignalRPole sRPole_My8cJpRB;
  SignalTabwrite sTabwrite_pdQH10sz;
  SignalTabwrite sTabwrite_LXLObLxv;
  SignalTabwrite sTabwrite_5JALhfJc;
  SignalTabwrite sTabwrite_5ts2noJC;
  SignalLine sLine_UOZ4ob1n;
  ControlVar cVar_FHnZSmmu;
  ControlVar cVar_AYuAIczb;
  ControlPack cPack_fEByXeW9;
  ControlBinop cBinop_pp0ULDWs;
  ControlVar cVar_f64ZcYqi;
  ControlPack cPack_Hp3dPUlN;
  ControlVar cVar_6aLfVu2s;
  ControlVar cVar_bbHhUxtj;
  ControlDelay cDelay_oXg7lhAa;
  ControlDelay cDelay_4qCmrLf2;
  ControlBinop cBinop_ubTKsrXV;
  HvTable hTable_gXBDIrkb;
  ControlBinop cBinop_710ZaHUW;
  ControlVar cVar_ZF0YUKC8;
  ControlBinop cBinop_h7fkhoct;
  ControlBinop cBinop_fNkP40Mt;
  SignalVarf sVarf_YVXgqNYD;
  SignalVarf sVarf_lIEZ0Mxl;
  SignalVarf sVarf_NrzILD28;
  ControlVar cVar_zJAhhKy7;
  ControlBinop cBinop_mFknCUJP;
  ControlBinop cBinop_ruPIZ8Jx;
  SignalVarf sVarf_nGZEviOs;
  SignalVarf sVarf_0AyXrPkI;
  SignalVarf sVarf_oefZTjOB;
  ControlBinop cBinop_8CQtU8SF;
  ControlBinop cBinop_2uSbcd42;
  ControlBinop cBinop_fcXaFhCI;
  ControlBinop cBinop_6VyR4WTW;
  ControlBinop cBinop_IJpJCaCG;
  ControlBinop cBinop_iV9UAcTY;
  ControlBinop cBinop_oP4NcYf0;
  ControlBinop cBinop_lyQ9JNLD;
  ControlBinop cBinop_WkPhcxYZ;
  SignalVarf sVarf_zb7oJVYw;
  ControlVar cVar_rmuZI1ZV;
  ControlBinop cBinop_fmATEhwo;
  ControlBinop cBinop_vJZrsRn4;
  ControlBinop cBinop_rxbUGsI1;
  ControlBinop cBinop_Ymra7Aaa;
  ControlBinop cBinop_l3OEoTOh;
  ControlBinop cBinop_bvn5vENf;
  ControlBinop cBinop_nNVuuYRN;
  SignalVarf sVarf_eSdQBy59;
  ControlBinop cBinop_vmQ29VkO;
  ControlRandom cRandom_HmIjCB38;
  ControlSlice cSlice_WgY0um3S;
  ControlDelay cDelay_FZcxPqHl;
  ControlVar cVar_tKrI5wgy;
  ControlBinop cBinop_oAiAeOPS;
  ControlBinop cBinop_UwxHwPJT;
  ControlBinop cBinop_4EQO4NJd;
  ControlTabhead cTabhead_Wnh3RMT8;
  ControlVar cVar_GEcAhmZ8;
  ControlDelay cDelay_VpL9vr7S;
  ControlDelay cDelay_MoLqPK5W;
  ControlBinop cBinop_Msyhrw2W;
  ControlBinop cBinop_zWe1jbEY;
  ControlBinop cBinop_vtLQcGWq;
  ControlBinop cBinop_fkBzNIhI;
  ControlBinop cBinop_Pgk2oe3x;
  ControlBinop cBinop_PxERa694;
  ControlTabhead cTabhead_CiaBiVUx;
  ControlVar cVar_AbUv6Rxa;
  ControlDelay cDelay_CjiAqkWJ;
  ControlDelay cDelay_VS2UJmMd;
  ControlBinop cBinop_AbCmk3fb;
  ControlBinop cBinop_ufhviyas;
  ControlBinop cBinop_3h0YZRPY;
  ControlBinop cBinop_Ri7s1YLQ;
  ControlBinop cBinop_Wqw0VOEm;
  ControlBinop cBinop_MYNXNCbX;
  ControlTabhead cTabhead_ZspbjrXY;
  ControlVar cVar_Zf3XSh8Q;
  ControlDelay cDelay_lcox6wgb;
  ControlDelay cDelay_sXvHxIO8;
  ControlBinop cBinop_nzHuNjWI;
  ControlBinop cBinop_9iYcvpRX;
  ControlBinop cBinop_1rDlXTZZ;
  ControlBinop cBinop_SpzAx2FK;
  ControlBinop cBinop_yyils2n0;
  ControlBinop cBinop_EE7tJCQi;
  ControlTabhead cTabhead_PZS2RrJp;
  ControlVar cVar_sY1p39Y5;
  ControlDelay cDelay_TTkKbmBY;
  ControlDelay cDelay_w9tOUnI1;
  ControlBinop cBinop_xzN6iPUr;
  ControlBinop cBinop_ZBzLs6ln;
  ControlBinop cBinop_qtZAhhcC;
  ControlBinop cBinop_ZBTQ9mpZ;
  ControlBinop cBinop_pa8DYYCT;
  ControlBinop cBinop_PneCyMRH;
  ControlDelay cDelay_nFsfUD5K;
  ControlDelay cDelay_dZsx4GYy;
  ControlBinop cBinop_5phpijmG;
  HvTable hTable_G51eVCsN;
  ControlBinop cBinop_ON7wBkiA;
  ControlDelay cDelay_MZsDU3dQ;
  ControlDelay cDelay_xdyVCdR1;
  ControlBinop cBinop_WuiRx2vW;
  HvTable hTable_G2YPXHz2;
  ControlBinop cBinop_H4angjxJ;
  ControlDelay cDelay_foZstvs7;
  ControlDelay cDelay_A0JBLtZF;
  ControlBinop cBinop_x79MWxft;
  HvTable hTable_fUthjX2E;
  ControlBinop cBinop_dLUGf1VO;
  ControlDelay cDelay_fSeJnMu5;
  ControlDelay cDelay_u5R27CFI;
  ControlBinop cBinop_gJfqSoTE;
  HvTable hTable_zWrps4fR;
  ControlBinop cBinop_clFyXaPG;
  ControlPack cPack_3PxPpXda;
  ControlPack cPack_3TK88cro;
  ControlBinop cBinop_negIeu0B;
  ControlBinop cBinop_QUvXvldK;
  ControlVar cVar_Zm8WJwS1;
  ControlBinop cBinop_eCuJr5cc;
  ControlBinop cBinop_y6MBQwia;
  SignalVarf sVarf_iZ6khDxT;
  ControlBinop cBinop_qY5qGXkV;
  ControlBinop cBinop_CFdGFFmk;
  ControlBinop cBinop_6Yj5DxO7;
  SignalVarf sVarf_qd0gNTtK;
  ControlVar cVar_JASygFtc;
  ControlVar cVar_kjlaU7dR;
  ControlVar cVar_E5GVivOF;
  ControlVar cVar_gxFiLM5W;
  ControlIf cIf_s6H3yt3Q;
  ControlBinop cBinop_0BrMQM3S;
  ControlBinop cBinop_am8TrKoZ;
  ControlBinop cBinop_7BkNrUiZ;
  ControlDelay cDelay_IQxw8B1y;
  ControlDelay cDelay_eaufajib;
  ControlBinop cBinop_HkqfqTjG;
  HvTable hTable_cH10QC8y;
  ControlBinop cBinop_XjWvGHcB;
  ControlTabhead cTabhead_Y0REFUsa;
  ControlVar cVar_W8TUcyVA;
  ControlDelay cDelay_osI1UkhA;
  ControlDelay cDelay_zhvWcdyM;
  ControlBinop cBinop_GhV1AHG8;
  ControlBinop cBinop_SolGE8k9;
  ControlBinop cBinop_qIdSZtaw;
  ControlBinop cBinop_JpC6CR20;
  ControlBinop cBinop_SAt5WDba;
  ControlBinop cBinop_rSbPKypg;
  ControlDelay cDelay_G1KZYr4w;
  ControlDelay cDelay_kPghd8IX;
  ControlBinop cBinop_JH71u3co;
  HvTable hTable_Roo2Fcq2;
  ControlBinop cBinop_OgSjAfgc;
  ControlTabhead cTabhead_VH7M8GlM;
  ControlVar cVar_WY62FWJH;
  ControlDelay cDelay_YEFQDZNF;
  ControlDelay cDelay_whp40bST;
  ControlBinop cBinop_e3qKJglz;
  ControlBinop cBinop_js3JqqMw;
  ControlBinop cBinop_CbSFuQkU;
  ControlBinop cBinop_1by74htG;
  ControlBinop cBinop_BLtSX5Nt;
  ControlBinop cBinop_83viiklP;
  ControlDelay cDelay_EOSEFU7P;
  ControlDelay cDelay_TsIae3iL;
  ControlBinop cBinop_V1KEHKdX;
  HvTable hTable_0CwqDI62;
  ControlBinop cBinop_loSCSMG7;
  ControlTabhead cTabhead_vhAZxxiF;
  ControlVar cVar_Sxa856Vc;
  ControlDelay cDelay_JHgqyc4t;
  ControlDelay cDelay_DE7IjjYx;
  ControlBinop cBinop_5ftnPcjG;
  ControlBinop cBinop_iWVu5jcI;
  ControlBinop cBinop_2IH3VvMQ;
  ControlBinop cBinop_DCmFQgMC;
  ControlBinop cBinop_adVqBGys;
  ControlBinop cBinop_mTRqwPe8;
  ControlDelay cDelay_V1quRLLa;
  ControlDelay cDelay_avV5j0eB;
  ControlBinop cBinop_hncopPsf;
  HvTable hTable_ZA2moZ9n;
  ControlBinop cBinop_3w4f86NM;
  ControlTabhead cTabhead_ZdFbYQZi;
  ControlVar cVar_dwx7zDra;
  ControlDelay cDelay_CwYxkmuL;
  ControlDelay cDelay_sVmIeNmm;
  ControlBinop cBinop_8ZvCB7qw;
  ControlBinop cBinop_cMybJsOI;
  ControlBinop cBinop_hlEyloRV;
  ControlBinop cBinop_k0hDJo0H;
  ControlBinop cBinop_nRh6PX8l;
  ControlBinop cBinop_Y38zgqIZ;
  ControlDelay cDelay_mXSNy8NC;
  ControlDelay cDelay_qQQi5lkX;
  ControlBinop cBinop_0P1zyKOC;
  HvTable hTable_Wpgscf8e;
  ControlBinop cBinop_Z9SpKXFT;
  ControlTabhead cTabhead_M4YvjE3d;
  ControlVar cVar_2gM0L0Cs;
  ControlDelay cDelay_f5OaB0aY;
  ControlDelay cDelay_ILNVgBHr;
  ControlBinop cBinop_IO5iS2JY;
  ControlBinop cBinop_FmMr1Dii;
  ControlBinop cBinop_qb7dKf6X;
  ControlBinop cBinop_j6GwZox3;
  ControlBinop cBinop_nqfn0pkh;
  ControlBinop cBinop_vlFvqLxG;
  ControlDelay cDelay_vZLKQigP;
  ControlDelay cDelay_1Jv9dk5d;
  ControlBinop cBinop_ey6aBt9j;
  HvTable hTable_Bc18DgJK;
  ControlBinop cBinop_pPmHePrI;
  ControlTabhead cTabhead_WbDquKYi;
  ControlVar cVar_GYrx9IoJ;
  ControlDelay cDelay_cR1RgjDh;
  ControlDelay cDelay_C1nYfjfg;
  ControlBinop cBinop_YvA25P6i;
  ControlBinop cBinop_DGtRWWqS;
  ControlBinop cBinop_xrFIWWTX;
  ControlBinop cBinop_PCVv96wW;
  ControlBinop cBinop_ZkxZMtCY;
  ControlBinop cBinop_27cGLCE9;
  ControlVar cVar_k4vFkX7E;
  ControlVar cVar_m4BmPXGq;
  ControlPack cPack_Poz53EhL;
  ControlVar cVar_cdfSlOpK;
  ControlBinop cBinop_vztiuzLw;
  ControlBinop cBinop_mtc3YiXw;
  SignalVarf sVarf_8lNzCTEj;
  ControlBinop cBinop_15ZXbyQ1;
  ControlBinop cBinop_Dv6nL3PM;
  ControlBinop cBinop_iRpF2klt;
  SignalVarf sVarf_fM7JrK0V;
  ControlVar cVar_qmmf0Boh;
  ControlBinop cBinop_COhrcvnM;
  ControlBinop cBinop_oDb0w1jv;
  SignalVarf sVarf_Qq6oXs2O;
  ControlBinop cBinop_UxDkckJw;
  ControlBinop cBinop_pl7QlUfc;
  ControlBinop cBinop_kYQUuT4u;
  SignalVarf sVarf_xFZvKuXj;
  ControlVar cVar_bpThspCY;
  ControlBinop cBinop_0shQaeDW;
  ControlBinop cBinop_7992qohC;
  SignalVarf sVarf_NTB7pA3n;
  ControlBinop cBinop_JMz3Syoh;
  ControlBinop cBinop_X0XjQ9th;
  ControlBinop cBinop_ZHbKVSxc;
  SignalVarf sVarf_lxeLbn2k;
  ControlBinop cBinop_dnIYyjab;
  ControlBinop cBinop_45FCAoQ5;
  ControlBinop cBinop_MjrkzQ1c;
  ControlDelay cDelay_ARWqrtDt;
  ControlVar cVar_3rzTJMvg;
  ControlBinop cBinop_M42j0Uuj;
  ControlBinop cBinop_z5982rr0;
  ControlBinop cBinop_Ltez59AZ;
  ControlVar cVar_PNUL1msZ;
  ControlVar cVar_yfdCz70C;
  ControlIf cIf_jDrqFIZH;
  ControlBinop cBinop_hBcwOdTO;
  ControlDelay cDelay_LSiPOQYU;
  ControlDelay cDelay_bu3PgdsA;
  ControlBinop cBinop_UGgEybp1;
  HvTable hTable_w7EEXtTy;
  ControlBinop cBinop_VLTsJLVQ;
  ControlTabhead cTabhead_Iouf9YOs;
  ControlVar cVar_LnmFpeLp;
  ControlDelay cDelay_pOOv638Q;
  ControlDelay cDelay_JnKXK1Ox;
  ControlBinop cBinop_9o3MTh3C;
  ControlBinop cBinop_PgRhJGoL;
  ControlBinop cBinop_qjAY3Fhg;
  ControlBinop cBinop_wBGPwcwI;
  ControlBinop cBinop_Mh5FVbzs;
  ControlBinop cBinop_AckfzlxZ;
  ControlVar cVar_1OrY7Jw7;
  ControlVar cVar_Vu7hOJp8;
  ControlVar cVar_JEk4GWQd;
  ControlVar cVar_OApjwMR5;
  ControlVar cVar_ElL8J4QU;
  ControlVar cVar_8Uyaaiu9;
  ControlIf cIf_iM2gjP27;
  ControlBinop cBinop_r4DmOdAo;
  ControlVar cVar_NrtNfVkp;
  ControlIf cIf_KI19z3ay;
  ControlBinop cBinop_bYg3wIxj;
  ControlSlice cSlice_Z4pddmu2;
  ControlSlice cSlice_zMDUu8l5;
  ControlVar cVar_HPREgDVc;
  ControlIf cIf_8KSwcUFn;
  ControlBinop cBinop_Nv31PhhK;
  ControlIf cIf_ozcZi3WJ;
  ControlIf cIf_5GKHX0Dh;
  ControlIf cIf_BkU321J5;
  ControlIf cIf_JDFAwEG3;
  ControlIf cIf_uC79O2e5;
  SignalVarf sVarf_y43jU9Rt;
  ControlBinop cBinop_5c88MSlC;
  ControlBinop cBinop_XxgqZNMw;
  ControlBinop cBinop_jkdJjAjM;
  ControlBinop cBinop_O2A17UeU;
  SignalVarf sVarf_XwQcfSML;
  ControlBinop cBinop_Jt11on4f;
  ControlBinop cBinop_ov6eoI1k;
  SignalVarf sVarf_cmx2s5AI;
  SignalVarf sVarf_2pYC7S7j;
  ControlBinop cBinop_vLgW4MmD;
  ControlBinop cBinop_pdEH01NG;
  ControlBinop cBinop_owG3A0Lm;
  ControlBinop cBinop_n1VAK7gC;
  ControlBinop cBinop_C3zuiNu7;
  ControlBinop cBinop_6Bw2LUh2;
  ControlBinop cBinop_mLlzFGAp;
  ControlBinop cBinop_MsKcz4LP;
  ControlBinop cBinop_K1txig4u;
  ControlBinop cBinop_R100i84R;
  ControlBinop cBinop_smHOyqhD;
  ControlBinop cBinop_Q0Wfoagc;
  ControlBinop cBinop_t8ohoFq1;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
