/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_z2Fj9mVh, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_RfoYL2qg);
  numBytes += sLine_init(&sLine_DklJ5SDZ);
  numBytes += sTabhead_init(&sTabhead_LHbrNcNF, &hTable_gXBDIrkb);
  numBytes += sTabread_init(&sTabread_2ytGmiKh, &hTable_gXBDIrkb, false);
  numBytes += sTabread_init(&sTabread_Irf27Rto, &hTable_gXBDIrkb, false);
  numBytes += sTabhead_init(&sTabhead_GpO4jdGa, &hTable_gXBDIrkb);
  numBytes += sTabread_init(&sTabread_w0yStSGH, &hTable_gXBDIrkb, false);
  numBytes += sTabread_init(&sTabread_G7u18Yvp, &hTable_gXBDIrkb, false);
  numBytes += sTabwrite_init(&sTabwrite_J5ScRWwu, &hTable_gXBDIrkb);
  numBytes += sRPole_init(&sRPole_P7VLnXF8);
  numBytes += sDel1_init(&sDel1_ufL71xut);
  numBytes += sTabread_init(&sTabread_nmBl8hTx, &hTable_w7EEXtTy, true);
  numBytes += sTabwrite_init(&sTabwrite_ILW0xCKI, &hTable_w7EEXtTy);
  numBytes += sTabread_init(&sTabread_Rh6a9PBr, &hTable_G51eVCsN, true);
  numBytes += sRPole_init(&sRPole_Xle4sjh6);
  numBytes += sLine_init(&sLine_8I3Zin3n);
  numBytes += sLine_init(&sLine_W3z52TUg);
  numBytes += sTabread_init(&sTabread_PNZNngt8, &hTable_cH10QC8y, true);
  numBytes += sTabread_init(&sTabread_sWPP1lIe, &hTable_Roo2Fcq2, true);
  numBytes += sTabread_init(&sTabread_pzk8qRlU, &hTable_0CwqDI62, true);
  numBytes += sTabread_init(&sTabread_rWbJFMc4, &hTable_ZA2moZ9n, true);
  numBytes += sTabread_init(&sTabread_d8CU25Ny, &hTable_Bc18DgJK, true);
  numBytes += sTabread_init(&sTabread_zoLt6y3U, &hTable_Wpgscf8e, true);
  numBytes += sTabwrite_init(&sTabwrite_tgbzZvny, &hTable_cH10QC8y);
  numBytes += sTabwrite_init(&sTabwrite_0s86JQUP, &hTable_Roo2Fcq2);
  numBytes += sTabwrite_init(&sTabwrite_u1ItxPrc, &hTable_0CwqDI62);
  numBytes += sTabwrite_init(&sTabwrite_YANjEak7, &hTable_ZA2moZ9n);
  numBytes += sTabwrite_init(&sTabwrite_6S4DHi75, &hTable_Wpgscf8e);
  numBytes += sTabwrite_init(&sTabwrite_70INXAA6, &hTable_Bc18DgJK);
  numBytes += sTabread_init(&sTabread_gwZ9hqgs, &hTable_G2YPXHz2, true);
  numBytes += sRPole_init(&sRPole_5voas3A2);
  numBytes += sTabread_init(&sTabread_ZltNwp5A, &hTable_fUthjX2E, true);
  numBytes += sRPole_init(&sRPole_ivYiGl13);
  numBytes += sTabread_init(&sTabread_DuDoObTu, &hTable_zWrps4fR, true);
  numBytes += sRPole_init(&sRPole_My8cJpRB);
  numBytes += sTabwrite_init(&sTabwrite_pdQH10sz, &hTable_G51eVCsN);
  numBytes += sTabwrite_init(&sTabwrite_LXLObLxv, &hTable_G2YPXHz2);
  numBytes += sTabwrite_init(&sTabwrite_5JALhfJc, &hTable_fUthjX2E);
  numBytes += sTabwrite_init(&sTabwrite_5ts2noJC, &hTable_zWrps4fR);
  numBytes += sLine_init(&sLine_UOZ4ob1n);
  numBytes += cVar_init_f(&cVar_FHnZSmmu, 0.0f);
  numBytes += cVar_init_f(&cVar_AYuAIczb, 0.0f);
  numBytes += cPack_init(&cPack_fEByXeW9, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_f64ZcYqi, 0.0f);
  numBytes += cPack_init(&cPack_Hp3dPUlN, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_6aLfVu2s, 0.0f);
  numBytes += cVar_init_f(&cVar_bbHhUxtj, 0.0f);
  numBytes += cDelay_init(this, &cDelay_oXg7lhAa, 0.0f);
  numBytes += cDelay_init(this, &cDelay_4qCmrLf2, 0.0f);
  numBytes += hTable_init(&hTable_gXBDIrkb, 256);
  numBytes += cVar_init_s(&cVar_ZF0YUKC8, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_YVXgqNYD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lIEZ0Mxl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NrzILD28, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_zJAhhKy7, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_nGZEviOs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0AyXrPkI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oefZTjOB, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_8CQtU8SF, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_zb7oJVYw, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_rmuZI1ZV, 0.0f);
  numBytes += cBinop_init(&cBinop_nNVuuYRN, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_eSdQBy59, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_HmIjCB38, -940882465);
  numBytes += cSlice_init(&cSlice_WgY0um3S, 1, 1);
  numBytes += cDelay_init(this, &cDelay_FZcxPqHl, 0.0f);
  numBytes += cVar_init_f(&cVar_tKrI5wgy, 5.0f);
  numBytes += cBinop_init(&cBinop_4EQO4NJd, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_Wnh3RMT8, &hTable_G51eVCsN);
  numBytes += cVar_init_s(&cVar_GEcAhmZ8, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_VpL9vr7S, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_MoLqPK5W, 0.0f);
  numBytes += cBinop_init(&cBinop_Msyhrw2W, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_vtLQcGWq, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_fkBzNIhI, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_PxERa694, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_CiaBiVUx, &hTable_G2YPXHz2);
  numBytes += cVar_init_s(&cVar_AbUv6Rxa, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_CjiAqkWJ, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_VS2UJmMd, 0.0f);
  numBytes += cBinop_init(&cBinop_AbCmk3fb, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_3h0YZRPY, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Ri7s1YLQ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_MYNXNCbX, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_ZspbjrXY, &hTable_fUthjX2E);
  numBytes += cVar_init_s(&cVar_Zf3XSh8Q, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_lcox6wgb, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_sXvHxIO8, 0.0f);
  numBytes += cBinop_init(&cBinop_nzHuNjWI, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_1rDlXTZZ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_SpzAx2FK, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_EE7tJCQi, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_PZS2RrJp, &hTable_zWrps4fR);
  numBytes += cVar_init_s(&cVar_sY1p39Y5, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_TTkKbmBY, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_w9tOUnI1, 0.0f);
  numBytes += cBinop_init(&cBinop_xzN6iPUr, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_qtZAhhcC, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ZBTQ9mpZ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_PneCyMRH, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_nFsfUD5K, 0.0f);
  numBytes += cDelay_init(this, &cDelay_dZsx4GYy, 0.0f);
  numBytes += hTable_init(&hTable_G51eVCsN, 256);
  numBytes += cDelay_init(this, &cDelay_MZsDU3dQ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_xdyVCdR1, 0.0f);
  numBytes += hTable_init(&hTable_G2YPXHz2, 256);
  numBytes += cDelay_init(this, &cDelay_foZstvs7, 0.0f);
  numBytes += cDelay_init(this, &cDelay_A0JBLtZF, 0.0f);
  numBytes += hTable_init(&hTable_fUthjX2E, 256);
  numBytes += cDelay_init(this, &cDelay_fSeJnMu5, 0.0f);
  numBytes += cDelay_init(this, &cDelay_u5R27CFI, 0.0f);
  numBytes += hTable_init(&hTable_zWrps4fR, 256);
  numBytes += cPack_init(&cPack_3PxPpXda, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_3TK88cro, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_Zm8WJwS1, 22050.0f);
  numBytes += cBinop_init(&cBinop_eCuJr5cc, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_iZ6khDxT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qd0gNTtK, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_JASygFtc, 0.0f);
  numBytes += cVar_init_f(&cVar_kjlaU7dR, 0.0f);
  numBytes += cVar_init_f(&cVar_E5GVivOF, 0.0f);
  numBytes += cVar_init_f(&cVar_gxFiLM5W, 0.0f);
  numBytes += cIf_init(&cIf_s6H3yt3Q, false);
  numBytes += cDelay_init(this, &cDelay_IQxw8B1y, 0.0f);
  numBytes += cDelay_init(this, &cDelay_eaufajib, 0.0f);
  numBytes += hTable_init(&hTable_cH10QC8y, 256);
  numBytes += cTabhead_init(&cTabhead_Y0REFUsa, &hTable_cH10QC8y);
  numBytes += cVar_init_s(&cVar_W8TUcyVA, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_osI1UkhA, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_zhvWcdyM, 0.0f);
  numBytes += cBinop_init(&cBinop_GhV1AHG8, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_qIdSZtaw, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_JpC6CR20, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_rSbPKypg, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_G1KZYr4w, 0.0f);
  numBytes += cDelay_init(this, &cDelay_kPghd8IX, 0.0f);
  numBytes += hTable_init(&hTable_Roo2Fcq2, 256);
  numBytes += cTabhead_init(&cTabhead_VH7M8GlM, &hTable_Roo2Fcq2);
  numBytes += cVar_init_s(&cVar_WY62FWJH, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_YEFQDZNF, 25.796f);
  numBytes += cDelay_init(this, &cDelay_whp40bST, 0.0f);
  numBytes += cBinop_init(&cBinop_e3qKJglz, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_CbSFuQkU, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_1by74htG, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_83viiklP, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_EOSEFU7P, 0.0f);
  numBytes += cDelay_init(this, &cDelay_TsIae3iL, 0.0f);
  numBytes += hTable_init(&hTable_0CwqDI62, 256);
  numBytes += cTabhead_init(&cTabhead_vhAZxxiF, &hTable_0CwqDI62);
  numBytes += cVar_init_s(&cVar_Sxa856Vc, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_JHgqyc4t, 19.392f);
  numBytes += cDelay_init(this, &cDelay_DE7IjjYx, 0.0f);
  numBytes += cBinop_init(&cBinop_5ftnPcjG, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_2IH3VvMQ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_DCmFQgMC, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_mTRqwPe8, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_V1quRLLa, 0.0f);
  numBytes += cDelay_init(this, &cDelay_avV5j0eB, 0.0f);
  numBytes += hTable_init(&hTable_ZA2moZ9n, 256);
  numBytes += cTabhead_init(&cTabhead_ZdFbYQZi, &hTable_ZA2moZ9n);
  numBytes += cVar_init_s(&cVar_dwx7zDra, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_CwYxkmuL, 16.364f);
  numBytes += cDelay_init(this, &cDelay_sVmIeNmm, 0.0f);
  numBytes += cBinop_init(&cBinop_8ZvCB7qw, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_hlEyloRV, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_k0hDJo0H, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Y38zgqIZ, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_mXSNy8NC, 0.0f);
  numBytes += cDelay_init(this, &cDelay_qQQi5lkX, 0.0f);
  numBytes += hTable_init(&hTable_Wpgscf8e, 256);
  numBytes += cTabhead_init(&cTabhead_M4YvjE3d, &hTable_Wpgscf8e);
  numBytes += cVar_init_s(&cVar_2gM0L0Cs, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_f5OaB0aY, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_ILNVgBHr, 0.0f);
  numBytes += cBinop_init(&cBinop_IO5iS2JY, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_qb7dKf6X, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_j6GwZox3, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_vlFvqLxG, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_vZLKQigP, 0.0f);
  numBytes += cDelay_init(this, &cDelay_1Jv9dk5d, 0.0f);
  numBytes += hTable_init(&hTable_Bc18DgJK, 256);
  numBytes += cTabhead_init(&cTabhead_WbDquKYi, &hTable_Bc18DgJK);
  numBytes += cVar_init_s(&cVar_GYrx9IoJ, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_cR1RgjDh, 7.645f);
  numBytes += cDelay_init(this, &cDelay_C1nYfjfg, 0.0f);
  numBytes += cBinop_init(&cBinop_YvA25P6i, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_xrFIWWTX, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_PCVv96wW, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_27cGLCE9, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_k4vFkX7E, 0.0f);
  numBytes += cVar_init_f(&cVar_m4BmPXGq, 0.0f);
  numBytes += cPack_init(&cPack_Poz53EhL, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_cdfSlOpK, 22050.0f);
  numBytes += cBinop_init(&cBinop_vztiuzLw, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_8lNzCTEj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fM7JrK0V, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_qmmf0Boh, 22050.0f);
  numBytes += cBinop_init(&cBinop_COhrcvnM, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Qq6oXs2O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xFZvKuXj, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_bpThspCY, 22050.0f);
  numBytes += cBinop_init(&cBinop_0shQaeDW, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_NTB7pA3n, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lxeLbn2k, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_ARWqrtDt, 0.0f);
  numBytes += cVar_init_f(&cVar_3rzTJMvg, 1000.0f);
  numBytes += cBinop_init(&cBinop_Ltez59AZ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_PNUL1msZ, 0.0f);
  numBytes += cVar_init_f(&cVar_yfdCz70C, 0.0f);
  numBytes += cIf_init(&cIf_jDrqFIZH, false);
  numBytes += cDelay_init(this, &cDelay_LSiPOQYU, 0.0f);
  numBytes += cDelay_init(this, &cDelay_bu3PgdsA, 0.0f);
  numBytes += hTable_init(&hTable_w7EEXtTy, 256);
  numBytes += cTabhead_init(&cTabhead_Iouf9YOs, &hTable_w7EEXtTy);
  numBytes += cVar_init_s(&cVar_LnmFpeLp, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_pOOv638Q, 150.0f);
  numBytes += cDelay_init(this, &cDelay_JnKXK1Ox, 0.0f);
  numBytes += cBinop_init(&cBinop_9o3MTh3C, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_qjAY3Fhg, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_wBGPwcwI, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_AckfzlxZ, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_1OrY7Jw7, 0.0f);
  numBytes += cVar_init_f(&cVar_Vu7hOJp8, 0.0f);
  numBytes += cVar_init_f(&cVar_JEk4GWQd, 0.0f);
  numBytes += cVar_init_f(&cVar_OApjwMR5, 0.0f);
  numBytes += cVar_init_f(&cVar_ElL8J4QU, 0.0f);
  numBytes += cVar_init_f(&cVar_8Uyaaiu9, 0.0f);
  numBytes += cIf_init(&cIf_iM2gjP27, false);
  numBytes += cVar_init_f(&cVar_NrtNfVkp, 0.0f);
  numBytes += cIf_init(&cIf_KI19z3ay, false);
  numBytes += cSlice_init(&cSlice_Z4pddmu2, 1, -1);
  numBytes += cSlice_init(&cSlice_zMDUu8l5, 1, -1);
  numBytes += cVar_init_f(&cVar_HPREgDVc, 0.0f);
  numBytes += cIf_init(&cIf_8KSwcUFn, false);
  numBytes += cBinop_init(&cBinop_Nv31PhhK, 0.0f); // __neq
  numBytes += cIf_init(&cIf_ozcZi3WJ, false);
  numBytes += cIf_init(&cIf_5GKHX0Dh, false);
  numBytes += cIf_init(&cIf_BkU321J5, false);
  numBytes += cIf_init(&cIf_JDFAwEG3, true);
  numBytes += cIf_init(&cIf_uC79O2e5, false);
  numBytes += sVarf_init(&sVarf_y43jU9Rt, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_jkdJjAjM, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_XwQcfSML, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_Jt11on4f, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ov6eoI1k, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_cmx2s5AI, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2pYC7S7j, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_pdEH01NG, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_K1txig4u, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_R100i84R, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_smHOyqhD, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Q0Wfoagc, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_t8ohoFq1, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_fEByXeW9);
  cPack_free(&cPack_Hp3dPUlN);
  hTable_free(&hTable_gXBDIrkb);
  hTable_free(&hTable_G51eVCsN);
  hTable_free(&hTable_G2YPXHz2);
  hTable_free(&hTable_fUthjX2E);
  hTable_free(&hTable_zWrps4fR);
  cPack_free(&cPack_3PxPpXda);
  cPack_free(&cPack_3TK88cro);
  hTable_free(&hTable_cH10QC8y);
  hTable_free(&hTable_Roo2Fcq2);
  hTable_free(&hTable_0CwqDI62);
  hTable_free(&hTable_ZA2moZ9n);
  hTable_free(&hTable_Wpgscf8e);
  hTable_free(&hTable_Bc18DgJK);
  cPack_free(&cPack_Poz53EhL);
  hTable_free(&hTable_w7EEXtTy);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_gXBDIrkb; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_G51eVCsN; // del-1052-del1
    case 0xA2AC524D: return &hTable_G2YPXHz2; // del-1052-del2
    case 0xE36A35B: return &hTable_fUthjX2E; // del-1052-del3
    case 0x48CE0509: return &hTable_zWrps4fR; // del-1052-del4
    case 0xE34D6E72: return &hTable_cH10QC8y; // del-1052-ref1
    case 0x6A1027AB: return &hTable_Roo2Fcq2; // del-1052-ref2
    case 0xA37C6D49: return &hTable_0CwqDI62; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_ZA2moZ9n; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_Wpgscf8e; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_Bc18DgJK; // del-1052-ref5
    case 0xED65564F: return &hTable_w7EEXtTy; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MVl0p7Qh_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JiQS9hV2_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7GP9dzfb_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TyP9iHWP_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0Camk34R_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iisfWxL4_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_im3mCUiX_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LMH1cg84_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_83AOxpgt_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xXGKSEzE_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jMzPCS1M_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pp8qtJxi_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dF9KIZPE_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QaVRAQGE_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QkW9AqnJ_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v6CQdCe7_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1DBY1Qxk_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pbGbXpte_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LsbYlL3u_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J9zWq8Hk_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZuUSAuIt_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dildUuMa_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eO17iq8i_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JAlARGNp_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_FHnZSmmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_6VyR4WTW_sendMessage);
}

void Heavy_ChaffVerb::cVar_AYuAIczb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_oP4NcYf0_sendMessage);
}

void Heavy_ChaffVerb::cPack_fEByXeW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_RfoYL2qg, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_3qkakvLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f64ZcYqi, 0, m, &cVar_f64ZcYqi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pp0ULDWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_3qkakvLL_sendMessage);
}

void Heavy_ChaffVerb::cVar_f64ZcYqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fcXaFhCI_sendMessage);
}

void Heavy_ChaffVerb::cPack_Hp3dPUlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_DklJ5SDZ, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_6aLfVu2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_iV9UAcTY_sendMessage);
}

void Heavy_ChaffVerb::cVar_bbHhUxtj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_z2Fj9mVh, 0, m);
}

void Heavy_ChaffVerb::cMsg_MJih7RnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AaxoYNxX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_AaxoYNxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_710ZaHUW_sendMessage);
}

void Heavy_ChaffVerb::cDelay_oXg7lhAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oXg7lhAa, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4qCmrLf2, 0, m, &cDelay_4qCmrLf2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oXg7lhAa, 0, m, &cDelay_oXg7lhAa_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_J5ScRWwu, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_4qCmrLf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4qCmrLf2, m);
  cMsg_7cyRms36_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_v8aPBuEN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_uXUeCVcR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_ubTKsrXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GRJQNsD8_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_gXBDIrkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U9U1IhgP_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oXg7lhAa, 2, m, &cDelay_oXg7lhAa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4hLc26fi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GRJQNsD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_gXBDIrkb, 0, m, &hTable_gXBDIrkb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_710ZaHUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_ubTKsrXV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7cyRms36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_gXBDIrkb, 0, m, &hTable_gXBDIrkb_sendMessage);
}

void Heavy_ChaffVerb::cCast_4hLc26fi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oXg7lhAa, 0, m, &cDelay_oXg7lhAa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_U9U1IhgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_4qCmrLf2, 2, m, &cDelay_4qCmrLf2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uXUeCVcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_J5ScRWwu, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_jSokIxI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2N6rXgLb_sendMessage);
}

void Heavy_ChaffVerb::cSystem_2N6rXgLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_h7fkhoct_sendMessage);
}

void Heavy_ChaffVerb::cVar_ZF0YUKC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2wrLH1nt_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_KSEPOaG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fNkP40Mt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YVXgqNYD, m);
}

void Heavy_ChaffVerb::cBinop_h7fkhoct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lIEZ0Mxl, m);
}

void Heavy_ChaffVerb::cMsg_2wrLH1nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KSEPOaG8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fNkP40Mt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_NrzILD28, m);
}

void Heavy_ChaffVerb::cMsg_rGaCA7pz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kPAEImOq_sendMessage);
}

void Heavy_ChaffVerb::cSystem_kPAEImOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_mFknCUJP_sendMessage);
}

void Heavy_ChaffVerb::cVar_zJAhhKy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gjrsjdfG_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_PE7Lo9TC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ruPIZ8Jx_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nGZEviOs, m);
}

void Heavy_ChaffVerb::cBinop_mFknCUJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0AyXrPkI, m);
}

void Heavy_ChaffVerb::cMsg_gjrsjdfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PE7Lo9TC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ruPIZ8Jx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_oefZTjOB, m);
}

void Heavy_ChaffVerb::cBinop_8CQtU8SF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bbHhUxtj, 0, m, &cVar_bbHhUxtj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2uSbcd42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K94Jrdb3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_necttOGI_sendMessage);
}

void Heavy_ChaffVerb::cCast_necttOGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8CQtU8SF, HV_BINOP_DIVIDE, 0, m, &cBinop_8CQtU8SF_sendMessage);
}

void Heavy_ChaffVerb::cCast_K94Jrdb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8CQtU8SF, HV_BINOP_DIVIDE, 1, m, &cBinop_8CQtU8SF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fcXaFhCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IJpJCaCG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6VyR4WTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_pp0ULDWs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IJpJCaCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8CQtU8SF, HV_BINOP_DIVIDE, 0, m, &cBinop_8CQtU8SF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iV9UAcTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Hp3dPUlN, 0, m, &cPack_Hp3dPUlN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oP4NcYf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_2uSbcd42_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_fEByXeW9, 0, m, &cPack_fEByXeW9_sendMessage);
}

void Heavy_ChaffVerb::cUnop_vik8tVeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5GKHX0Dh, 0, m, &cIf_5GKHX0Dh_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_q0FVTB1S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0EpOW7Dp_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DEKMxhfz_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U7JBwdiz_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_0EpOW7Dp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KlS64hBH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_DEKMxhfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EUpHWQzd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_U7JBwdiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VXOjUwu6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_lyQ9JNLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_WkPhcxYZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WkPhcxYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fmATEhwo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Ymra7Aaa_sendMessage);
}

void Heavy_ChaffVerb::cVar_rmuZI1ZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_l3OEoTOh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Rr2AqyTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CCVccWdU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_CCVccWdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nNVuuYRN, HV_BINOP_DIVIDE, 1, m, &cBinop_nNVuuYRN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fmATEhwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vJZrsRn4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vJZrsRn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_eSdQBy59, m);
}

void Heavy_ChaffVerb::cMsg_3WVsk0t1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rxbUGsI1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rxbUGsI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_lyQ9JNLD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ymra7Aaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zb7oJVYw, m);
}

void Heavy_ChaffVerb::cBinop_l3OEoTOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_bvn5vENf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bvn5vENf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nNVuuYRN, HV_BINOP_DIVIDE, 0, m, &cBinop_nNVuuYRN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nNVuuYRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3WVsk0t1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_SDPBmrwp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WgY0um3S, 0, m, &cSlice_WgY0um3S_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_HmIjCB38, 0, m, &cRandom_HmIjCB38_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_vmQ29VkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_S7poB7Qs_sendMessage);
}

void Heavy_ChaffVerb::cUnop_S7poB7Qs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_XxgqZNMw_sendMessage);
}

void Heavy_ChaffVerb::cRandom_HmIjCB38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_vmQ29VkO_sendMessage);
}

void Heavy_ChaffVerb::cSlice_WgY0um3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_HmIjCB38, 1, m, &cRandom_HmIjCB38_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_0U82drI4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_ACZgaO8r_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_ACZgaO8r_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mNPr7Il6_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_FZcxPqHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FZcxPqHl, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FZcxPqHl, 0, m, &cDelay_FZcxPqHl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PNUL1msZ, 0, m, &cVar_PNUL1msZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_mNPr7Il6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ACZgaO8r_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FZcxPqHl, 0, m, &cDelay_FZcxPqHl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PNUL1msZ, 0, m, &cVar_PNUL1msZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LP5M2Wvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vqxii9Bk_sendMessage);
}

void Heavy_ChaffVerb::cSystem_vqxii9Bk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UwxHwPJT_sendMessage);
}

void Heavy_ChaffVerb::cVar_tKrI5wgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4EQO4NJd, HV_BINOP_MULTIPLY, 0, m, &cBinop_4EQO4NJd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ACZgaO8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FZcxPqHl, 0, m, &cDelay_FZcxPqHl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oAiAeOPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FZcxPqHl, 2, m, &cDelay_FZcxPqHl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UwxHwPJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4EQO4NJd, HV_BINOP_MULTIPLY, 1, m, &cBinop_4EQO4NJd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4EQO4NJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_oAiAeOPS_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_Wnh3RMT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vtLQcGWq, HV_BINOP_SUBTRACT, 0, m, &cBinop_vtLQcGWq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_I79T9ylW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_36xnQg8X_sendMessage);
}

void Heavy_ChaffVerb::cSystem_36xnQg8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zWe1jbEY_sendMessage);
}

void Heavy_ChaffVerb::cVar_GEcAhmZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SF6ZhLYy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_VpL9vr7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VpL9vr7S, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MoLqPK5W, 0, m, &cDelay_MoLqPK5W_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Rh6a9PBr, 0, m, &sTabread_Rh6a9PBr_sendMessage);
}

void Heavy_ChaffVerb::cDelay_MoLqPK5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MoLqPK5W, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Rh6a9PBr, 0, m, &sTabread_Rh6a9PBr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MoLqPK5W, 0, m, &cDelay_MoLqPK5W_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Rh6a9PBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_PxERa694, HV_BINOP_SUBTRACT, 0, m, &cBinop_PxERa694_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_Msyhrw2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fkBzNIhI, HV_BINOP_MAX, 0, m, &cBinop_fkBzNIhI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zWe1jbEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Msyhrw2W, HV_BINOP_MULTIPLY, 0, m, &cBinop_Msyhrw2W_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vtLQcGWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N2RnpxVE_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Rh6a9PBr, 0, m, &sTabread_Rh6a9PBr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jAjqo2Xr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_g17VCosP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PxERa694, HV_BINOP_SUBTRACT, 1, m, &cBinop_PxERa694_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MoLqPK5W, 2, m, &cDelay_MoLqPK5W_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SF6ZhLYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_g17VCosP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_N2RnpxVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VpL9vr7S, 0, m, &cDelay_VpL9vr7S_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MoLqPK5W, 0, m, &cDelay_MoLqPK5W_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hCTW0WZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_fkBzNIhI, HV_BINOP_MAX, 1, m, &cBinop_fkBzNIhI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fkBzNIhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vtLQcGWq, HV_BINOP_SUBTRACT, 1, m, &cBinop_vtLQcGWq_sendMessage);
}

void Heavy_ChaffVerb::cCast_jAjqo2Xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VpL9vr7S, 0, m, &cDelay_VpL9vr7S_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Pgk2oe3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VpL9vr7S, 2, m, &cDelay_VpL9vr7S_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PxERa694_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Pgk2oe3x_sendMessage);
}

void Heavy_ChaffVerb::cCast_f2JtkpSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GEcAhmZ8, 0, m, &cVar_GEcAhmZ8_sendMessage);
  cMsg_I79T9ylW_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Wnh3RMT8, 0, m, &cTabhead_Wnh3RMT8_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_CiaBiVUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3h0YZRPY, HV_BINOP_SUBTRACT, 0, m, &cBinop_3h0YZRPY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NWDNlvmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LrjqdN8q_sendMessage);
}

void Heavy_ChaffVerb::cSystem_LrjqdN8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ufhviyas_sendMessage);
}

void Heavy_ChaffVerb::cVar_AbUv6Rxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NceNdnju_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_CjiAqkWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CjiAqkWJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VS2UJmMd, 0, m, &cDelay_VS2UJmMd_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gwZ9hqgs, 0, m, &sTabread_gwZ9hqgs_sendMessage);
}

void Heavy_ChaffVerb::cDelay_VS2UJmMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VS2UJmMd, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gwZ9hqgs, 0, m, &sTabread_gwZ9hqgs_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VS2UJmMd, 0, m, &cDelay_VS2UJmMd_sendMessage);
}

void Heavy_ChaffVerb::sTabread_gwZ9hqgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_MYNXNCbX, HV_BINOP_SUBTRACT, 0, m, &cBinop_MYNXNCbX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_AbCmk3fb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ri7s1YLQ, HV_BINOP_MAX, 0, m, &cBinop_Ri7s1YLQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ufhviyas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AbCmk3fb, HV_BINOP_MULTIPLY, 0, m, &cBinop_AbCmk3fb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3h0YZRPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AhdkYPAX_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gwZ9hqgs, 0, m, &sTabread_gwZ9hqgs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AnKttOcl_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ovicBIU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MYNXNCbX, HV_BINOP_SUBTRACT, 1, m, &cBinop_MYNXNCbX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VS2UJmMd, 2, m, &cDelay_VS2UJmMd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NceNdnju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ovicBIU4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AhdkYPAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CjiAqkWJ, 0, m, &cDelay_CjiAqkWJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VS2UJmMd, 0, m, &cDelay_VS2UJmMd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pOwbymw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ri7s1YLQ, HV_BINOP_MAX, 1, m, &cBinop_Ri7s1YLQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ri7s1YLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3h0YZRPY, HV_BINOP_SUBTRACT, 1, m, &cBinop_3h0YZRPY_sendMessage);
}

void Heavy_ChaffVerb::cCast_AnKttOcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CjiAqkWJ, 0, m, &cDelay_CjiAqkWJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Wqw0VOEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CjiAqkWJ, 2, m, &cDelay_CjiAqkWJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MYNXNCbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Wqw0VOEm_sendMessage);
}

void Heavy_ChaffVerb::cCast_W1OcCjIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AbUv6Rxa, 0, m, &cVar_AbUv6Rxa_sendMessage);
  cMsg_NWDNlvmu_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_CiaBiVUx, 0, m, &cTabhead_CiaBiVUx_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_ZspbjrXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1rDlXTZZ, HV_BINOP_SUBTRACT, 0, m, &cBinop_1rDlXTZZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Jo6SmE9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RJ8ZYwS1_sendMessage);
}

void Heavy_ChaffVerb::cSystem_RJ8ZYwS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9iYcvpRX_sendMessage);
}

void Heavy_ChaffVerb::cVar_Zf3XSh8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LgKiizjO_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_lcox6wgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lcox6wgb, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sXvHxIO8, 0, m, &cDelay_sXvHxIO8_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ZltNwp5A, 0, m, &sTabread_ZltNwp5A_sendMessage);
}

void Heavy_ChaffVerb::cDelay_sXvHxIO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sXvHxIO8, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ZltNwp5A, 0, m, &sTabread_ZltNwp5A_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sXvHxIO8, 0, m, &cDelay_sXvHxIO8_sendMessage);
}

void Heavy_ChaffVerb::sTabread_ZltNwp5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_EE7tJCQi, HV_BINOP_SUBTRACT, 0, m, &cBinop_EE7tJCQi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_nzHuNjWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SpzAx2FK, HV_BINOP_MAX, 0, m, &cBinop_SpzAx2FK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9iYcvpRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nzHuNjWI, HV_BINOP_MULTIPLY, 0, m, &cBinop_nzHuNjWI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1rDlXTZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BT5Kry0L_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ZltNwp5A, 0, m, &sTabread_ZltNwp5A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8Q2Z1OgR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_xbmDQcaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EE7tJCQi, HV_BINOP_SUBTRACT, 1, m, &cBinop_EE7tJCQi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sXvHxIO8, 2, m, &cDelay_sXvHxIO8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LgKiizjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xbmDQcaS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BT5Kry0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lcox6wgb, 0, m, &cDelay_lcox6wgb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sXvHxIO8, 0, m, &cDelay_sXvHxIO8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RHf8NP5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_SpzAx2FK, HV_BINOP_MAX, 1, m, &cBinop_SpzAx2FK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SpzAx2FK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1rDlXTZZ, HV_BINOP_SUBTRACT, 1, m, &cBinop_1rDlXTZZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_8Q2Z1OgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lcox6wgb, 0, m, &cDelay_lcox6wgb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yyils2n0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lcox6wgb, 2, m, &cDelay_lcox6wgb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EE7tJCQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yyils2n0_sendMessage);
}

void Heavy_ChaffVerb::cCast_fUkk7lR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zf3XSh8Q, 0, m, &cVar_Zf3XSh8Q_sendMessage);
  cMsg_Jo6SmE9X_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ZspbjrXY, 0, m, &cTabhead_ZspbjrXY_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_PZS2RrJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qtZAhhcC, HV_BINOP_SUBTRACT, 0, m, &cBinop_qtZAhhcC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_A7w72u7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0L9lskoP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0L9lskoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZBzLs6ln_sendMessage);
}

void Heavy_ChaffVerb::cVar_sY1p39Y5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6xic4mpd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_TTkKbmBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TTkKbmBY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w9tOUnI1, 0, m, &cDelay_w9tOUnI1_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_DuDoObTu, 0, m, &sTabread_DuDoObTu_sendMessage);
}

void Heavy_ChaffVerb::cDelay_w9tOUnI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_w9tOUnI1, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_DuDoObTu, 0, m, &sTabread_DuDoObTu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w9tOUnI1, 0, m, &cDelay_w9tOUnI1_sendMessage);
}

void Heavy_ChaffVerb::sTabread_DuDoObTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_PneCyMRH, HV_BINOP_SUBTRACT, 0, m, &cBinop_PneCyMRH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_xzN6iPUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZBTQ9mpZ, HV_BINOP_MAX, 0, m, &cBinop_ZBTQ9mpZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZBzLs6ln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xzN6iPUr, HV_BINOP_MULTIPLY, 0, m, &cBinop_xzN6iPUr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qtZAhhcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0rGpzGcD_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_DuDoObTu, 0, m, &sTabread_DuDoObTu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lyGEeHZS_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0TbPoHYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PneCyMRH, HV_BINOP_SUBTRACT, 1, m, &cBinop_PneCyMRH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w9tOUnI1, 2, m, &cDelay_w9tOUnI1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6xic4mpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0TbPoHYe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0rGpzGcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TTkKbmBY, 0, m, &cDelay_TTkKbmBY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w9tOUnI1, 0, m, &cDelay_w9tOUnI1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vU76c0BS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZBTQ9mpZ, HV_BINOP_MAX, 1, m, &cBinop_ZBTQ9mpZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZBTQ9mpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qtZAhhcC, HV_BINOP_SUBTRACT, 1, m, &cBinop_qtZAhhcC_sendMessage);
}

void Heavy_ChaffVerb::cCast_lyGEeHZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TTkKbmBY, 0, m, &cDelay_TTkKbmBY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pa8DYYCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TTkKbmBY, 2, m, &cDelay_TTkKbmBY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PneCyMRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_pa8DYYCT_sendMessage);
}

void Heavy_ChaffVerb::cCast_xL4EfCUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sY1p39Y5, 0, m, &cVar_sY1p39Y5_sendMessage);
  cMsg_A7w72u7b_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_PZS2RrJp, 0, m, &cTabhead_PZS2RrJp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6d3ZrZFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4Bo6NYsE_sendMessage);
}

void Heavy_ChaffVerb::cSystem_4Bo6NYsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ON7wBkiA_sendMessage);
}

void Heavy_ChaffVerb::cDelay_nFsfUD5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nFsfUD5K, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dZsx4GYy, 0, m, &cDelay_dZsx4GYy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nFsfUD5K, 0, m, &cDelay_nFsfUD5K_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pdQH10sz, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_dZsx4GYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dZsx4GYy, m);
  cMsg_YN1pWldm_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_TV2vvmyJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_pZE3mbBn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_5phpijmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nJuILwB8_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_G51eVCsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h1CcruBh_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nFsfUD5K, 2, m, &cDelay_nFsfUD5K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pEyBKuUP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nJuILwB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_G51eVCsN, 0, m, &hTable_G51eVCsN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ON7wBkiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_5phpijmG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YN1pWldm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_G51eVCsN, 0, m, &hTable_G51eVCsN_sendMessage);
}

void Heavy_ChaffVerb::cCast_pEyBKuUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nFsfUD5K, 0, m, &cDelay_nFsfUD5K_sendMessage);
}

void Heavy_ChaffVerb::cMsg_h1CcruBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_dZsx4GYy, 2, m, &cDelay_dZsx4GYy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pZE3mbBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pdQH10sz, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_mRpRHhWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iTcSiq48_sendMessage);
}

void Heavy_ChaffVerb::cSystem_iTcSiq48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_H4angjxJ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_MZsDU3dQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MZsDU3dQ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xdyVCdR1, 0, m, &cDelay_xdyVCdR1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MZsDU3dQ, 0, m, &cDelay_MZsDU3dQ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LXLObLxv, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_xdyVCdR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xdyVCdR1, m);
  cMsg_mvQX2J91_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_4OtOTJ8D_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_4JpHNtQ2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_WuiRx2vW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UEpkr8Ih_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_G2YPXHz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ygi9rJ84_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MZsDU3dQ, 2, m, &cDelay_MZsDU3dQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2yVtVknV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UEpkr8Ih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_G2YPXHz2, 0, m, &hTable_G2YPXHz2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_H4angjxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_WuiRx2vW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mvQX2J91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_G2YPXHz2, 0, m, &hTable_G2YPXHz2_sendMessage);
}

void Heavy_ChaffVerb::cCast_2yVtVknV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MZsDU3dQ, 0, m, &cDelay_MZsDU3dQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ygi9rJ84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_xdyVCdR1, 2, m, &cDelay_xdyVCdR1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4JpHNtQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LXLObLxv, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_NK27DJdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FsPe6vkY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FsPe6vkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_dLUGf1VO_sendMessage);
}

void Heavy_ChaffVerb::cDelay_foZstvs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_foZstvs7, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_A0JBLtZF, 0, m, &cDelay_A0JBLtZF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_foZstvs7, 0, m, &cDelay_foZstvs7_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5JALhfJc, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_A0JBLtZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_A0JBLtZF, m);
  cMsg_i1973J8u_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_wesIENsN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_BZbaocDv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_x79MWxft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sNseJstW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_fUthjX2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_agWThiKY_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_foZstvs7, 2, m, &cDelay_foZstvs7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q53wQgBb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sNseJstW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_fUthjX2E, 0, m, &hTable_fUthjX2E_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dLUGf1VO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_x79MWxft_sendMessage);
}

void Heavy_ChaffVerb::cMsg_i1973J8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_fUthjX2E, 0, m, &hTable_fUthjX2E_sendMessage);
}

void Heavy_ChaffVerb::cCast_Q53wQgBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_foZstvs7, 0, m, &cDelay_foZstvs7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_agWThiKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_A0JBLtZF, 2, m, &cDelay_A0JBLtZF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BZbaocDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5JALhfJc, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_DDCxZUpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Oq2JYx7e_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Oq2JYx7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_clFyXaPG_sendMessage);
}

void Heavy_ChaffVerb::cDelay_fSeJnMu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fSeJnMu5, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u5R27CFI, 0, m, &cDelay_u5R27CFI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fSeJnMu5, 0, m, &cDelay_fSeJnMu5_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5ts2noJC, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_u5R27CFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_u5R27CFI, m);
  cMsg_ZzDjFtNE_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_YA27dO6m_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_yYw9eTa1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_gJfqSoTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B6h9DG3Q_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_zWrps4fR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zcwghlIB_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fSeJnMu5, 2, m, &cDelay_fSeJnMu5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F5ltni6R_sendMessage);
}

void Heavy_ChaffVerb::cMsg_B6h9DG3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_zWrps4fR, 0, m, &hTable_zWrps4fR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_clFyXaPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_gJfqSoTE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZzDjFtNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_zWrps4fR, 0, m, &hTable_zWrps4fR_sendMessage);
}

void Heavy_ChaffVerb::cCast_F5ltni6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fSeJnMu5, 0, m, &cDelay_fSeJnMu5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zcwghlIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_u5R27CFI, 2, m, &cDelay_u5R27CFI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yYw9eTa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5ts2noJC, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_3PxPpXda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_UOZ4ob1n, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_3TK88cro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_W3z52TUg, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_negIeu0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_QUvXvldK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QUvXvldK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_dnIYyjab_sendMessage);
}

void Heavy_ChaffVerb::cVar_Zm8WJwS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eCuJr5cc, HV_BINOP_MULTIPLY, 0, m, &cBinop_eCuJr5cc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_F9sXnCIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qjw0qzwc_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qjw0qzwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8mYPdYyy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_eCuJr5cc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qY5qGXkV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_y6MBQwia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eCuJr5cc, HV_BINOP_MULTIPLY, 1, m, &cBinop_eCuJr5cc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8mYPdYyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_y6MBQwia_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qY5qGXkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_CFdGFFmk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CFdGFFmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6Yj5DxO7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qd0gNTtK, m);
}

void Heavy_ChaffVerb::cBinop_6Yj5DxO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_iZ6khDxT, m);
}

void Heavy_ChaffVerb::cVar_JASygFtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_MjrkzQ1c_sendMessage);
}

void Heavy_ChaffVerb::cVar_kjlaU7dR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_negIeu0B_sendMessage);
}

void Heavy_ChaffVerb::cVar_E5GVivOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_0BrMQM3S_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_s6H3yt3Q, 0, m, &cIf_s6H3yt3Q_sendMessage);
}

void Heavy_ChaffVerb::cVar_gxFiLM5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_am8TrKoZ_sendMessage);
}

void Heavy_ChaffVerb::cIf_s6H3yt3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_c46fFnHc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_k4vFkX7E, 0, m, &cVar_k4vFkX7E_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_0BrMQM3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s6H3yt3Q, 1, m, &cIf_s6H3yt3Q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_am8TrKoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7BkNrUiZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7BkNrUiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m4BmPXGq, 0, m, &cVar_m4BmPXGq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ItU380X9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KW3kZjL9_sendMessage);
}

void Heavy_ChaffVerb::cSystem_KW3kZjL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XjWvGHcB_sendMessage);
}

void Heavy_ChaffVerb::cDelay_IQxw8B1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IQxw8B1y, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eaufajib, 0, m, &cDelay_eaufajib_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IQxw8B1y, 0, m, &cDelay_IQxw8B1y_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_tgbzZvny, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_eaufajib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eaufajib, m);
  cMsg_eDviefti_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_aIqeqSOo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wlwH7ecd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_HkqfqTjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2pplyCnX_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_cH10QC8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qSBxmppU_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IQxw8B1y, 2, m, &cDelay_IQxw8B1y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MU1Ba0HD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2pplyCnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_cH10QC8y, 0, m, &hTable_cH10QC8y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XjWvGHcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_HkqfqTjG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_eDviefti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_cH10QC8y, 0, m, &hTable_cH10QC8y_sendMessage);
}

void Heavy_ChaffVerb::cCast_MU1Ba0HD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IQxw8B1y, 0, m, &cDelay_IQxw8B1y_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qSBxmppU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_eaufajib, 2, m, &cDelay_eaufajib_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wlwH7ecd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_tgbzZvny, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_Y0REFUsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qIdSZtaw, HV_BINOP_SUBTRACT, 0, m, &cBinop_qIdSZtaw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yMuuykJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_s1YHWc4f_sendMessage);
}

void Heavy_ChaffVerb::cSystem_s1YHWc4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_SolGE8k9_sendMessage);
}

void Heavy_ChaffVerb::cVar_W8TUcyVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sRZSFEZm_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_osI1UkhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_osI1UkhA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zhvWcdyM, 0, m, &cDelay_zhvWcdyM_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PNZNngt8, 0, m, &sTabread_PNZNngt8_sendMessage);
}

void Heavy_ChaffVerb::cDelay_zhvWcdyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zhvWcdyM, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PNZNngt8, 0, m, &sTabread_PNZNngt8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zhvWcdyM, 0, m, &cDelay_zhvWcdyM_sendMessage);
}

void Heavy_ChaffVerb::sTabread_PNZNngt8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_rSbPKypg, HV_BINOP_SUBTRACT, 0, m, &cBinop_rSbPKypg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_GhV1AHG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JpC6CR20, HV_BINOP_MAX, 0, m, &cBinop_JpC6CR20_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SolGE8k9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GhV1AHG8, HV_BINOP_MULTIPLY, 0, m, &cBinop_GhV1AHG8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qIdSZtaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QvuklLqQ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PNZNngt8, 0, m, &sTabread_PNZNngt8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ndr9obp7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ZXiWotnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rSbPKypg, HV_BINOP_SUBTRACT, 1, m, &cBinop_rSbPKypg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zhvWcdyM, 2, m, &cDelay_zhvWcdyM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sRZSFEZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZXiWotnN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QvuklLqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_osI1UkhA, 0, m, &cDelay_osI1UkhA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zhvWcdyM, 0, m, &cDelay_zhvWcdyM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hAYm6QZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_JpC6CR20, HV_BINOP_MAX, 1, m, &cBinop_JpC6CR20_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JpC6CR20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qIdSZtaw, HV_BINOP_SUBTRACT, 1, m, &cBinop_qIdSZtaw_sendMessage);
}

void Heavy_ChaffVerb::cCast_Ndr9obp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_osI1UkhA, 0, m, &cDelay_osI1UkhA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SAt5WDba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_osI1UkhA, 2, m, &cDelay_osI1UkhA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rSbPKypg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SAt5WDba_sendMessage);
}

void Heavy_ChaffVerb::cCast_F3BP3afM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W8TUcyVA, 0, m, &cVar_W8TUcyVA_sendMessage);
  cMsg_yMuuykJq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Y0REFUsa, 0, m, &cTabhead_Y0REFUsa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7d6qzdSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tlpaSdB4_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tlpaSdB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_OgSjAfgc_sendMessage);
}

void Heavy_ChaffVerb::cDelay_G1KZYr4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_G1KZYr4w, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kPghd8IX, 0, m, &cDelay_kPghd8IX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_G1KZYr4w, 0, m, &cDelay_G1KZYr4w_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_0s86JQUP, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_kPghd8IX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kPghd8IX, m);
  cMsg_dNRRvYKq_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_eH8aknWv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_95DWPg47_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_JH71u3co_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IeKmhonz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Roo2Fcq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v9hUuOK8_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_G1KZYr4w, 2, m, &cDelay_G1KZYr4w_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8NkHWBuC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IeKmhonz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Roo2Fcq2, 0, m, &hTable_Roo2Fcq2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OgSjAfgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_JH71u3co_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dNRRvYKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Roo2Fcq2, 0, m, &hTable_Roo2Fcq2_sendMessage);
}

void Heavy_ChaffVerb::cCast_8NkHWBuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_G1KZYr4w, 0, m, &cDelay_G1KZYr4w_sendMessage);
}

void Heavy_ChaffVerb::cMsg_v9hUuOK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_kPghd8IX, 2, m, &cDelay_kPghd8IX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_95DWPg47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_0s86JQUP, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_VH7M8GlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CbSFuQkU, HV_BINOP_SUBTRACT, 0, m, &cBinop_CbSFuQkU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_voTo4a3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PpyDSycw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_PpyDSycw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_js3JqqMw_sendMessage);
}

void Heavy_ChaffVerb::cVar_WY62FWJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6AFsTkDK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_YEFQDZNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YEFQDZNF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_whp40bST, 0, m, &cDelay_whp40bST_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_sWPP1lIe, 0, m, &sTabread_sWPP1lIe_sendMessage);
}

void Heavy_ChaffVerb::cDelay_whp40bST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_whp40bST, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_sWPP1lIe, 0, m, &sTabread_sWPP1lIe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_whp40bST, 0, m, &cDelay_whp40bST_sendMessage);
}

void Heavy_ChaffVerb::sTabread_sWPP1lIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_83viiklP, HV_BINOP_SUBTRACT, 0, m, &cBinop_83viiklP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_e3qKJglz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1by74htG, HV_BINOP_MAX, 0, m, &cBinop_1by74htG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_js3JqqMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e3qKJglz, HV_BINOP_MULTIPLY, 0, m, &cBinop_e3qKJglz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CbSFuQkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yCDYS6jg_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_sWPP1lIe, 0, m, &sTabread_sWPP1lIe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q8lFqXGB_sendMessage);
}

void Heavy_ChaffVerb::cSystem_fHlD2hPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_83viiklP, HV_BINOP_SUBTRACT, 1, m, &cBinop_83viiklP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_whp40bST, 2, m, &cDelay_whp40bST_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6AFsTkDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fHlD2hPl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yCDYS6jg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YEFQDZNF, 0, m, &cDelay_YEFQDZNF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_whp40bST, 0, m, &cDelay_whp40bST_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fqwDgtwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_1by74htG, HV_BINOP_MAX, 1, m, &cBinop_1by74htG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1by74htG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CbSFuQkU, HV_BINOP_SUBTRACT, 1, m, &cBinop_CbSFuQkU_sendMessage);
}

void Heavy_ChaffVerb::cCast_Q8lFqXGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YEFQDZNF, 0, m, &cDelay_YEFQDZNF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BLtSX5Nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YEFQDZNF, 2, m, &cDelay_YEFQDZNF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_83viiklP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BLtSX5Nt_sendMessage);
}

void Heavy_ChaffVerb::cCast_mmyyH3T4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WY62FWJH, 0, m, &cVar_WY62FWJH_sendMessage);
  cMsg_voTo4a3X_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_VH7M8GlM, 0, m, &cTabhead_VH7M8GlM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_s8yrEN62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hrjHhpXn_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hrjHhpXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_loSCSMG7_sendMessage);
}

void Heavy_ChaffVerb::cDelay_EOSEFU7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EOSEFU7P, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TsIae3iL, 0, m, &cDelay_TsIae3iL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EOSEFU7P, 0, m, &cDelay_EOSEFU7P_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_u1ItxPrc, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_TsIae3iL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TsIae3iL, m);
  cMsg_A1o5GbAp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_KYHiukOX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_n6RyzBJH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_V1KEHKdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bR26T3Hc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_0CwqDI62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2QqFCrGC_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EOSEFU7P, 2, m, &cDelay_EOSEFU7P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p3xfcfkK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bR26T3Hc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_0CwqDI62, 0, m, &hTable_0CwqDI62_sendMessage);
}

void Heavy_ChaffVerb::cBinop_loSCSMG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_V1KEHKdX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_A1o5GbAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_0CwqDI62, 0, m, &hTable_0CwqDI62_sendMessage);
}

void Heavy_ChaffVerb::cCast_p3xfcfkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EOSEFU7P, 0, m, &cDelay_EOSEFU7P_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2QqFCrGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_TsIae3iL, 2, m, &cDelay_TsIae3iL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_n6RyzBJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_u1ItxPrc, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_vhAZxxiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2IH3VvMQ, HV_BINOP_SUBTRACT, 0, m, &cBinop_2IH3VvMQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GWNibYnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_w9I5Ze8q_sendMessage);
}

void Heavy_ChaffVerb::cSystem_w9I5Ze8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_iWVu5jcI_sendMessage);
}

void Heavy_ChaffVerb::cVar_Sxa856Vc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O8kxrxOA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_JHgqyc4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JHgqyc4t, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DE7IjjYx, 0, m, &cDelay_DE7IjjYx_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pzk8qRlU, 0, m, &sTabread_pzk8qRlU_sendMessage);
}

void Heavy_ChaffVerb::cDelay_DE7IjjYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DE7IjjYx, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pzk8qRlU, 0, m, &sTabread_pzk8qRlU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DE7IjjYx, 0, m, &cDelay_DE7IjjYx_sendMessage);
}

void Heavy_ChaffVerb::sTabread_pzk8qRlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_mTRqwPe8, HV_BINOP_SUBTRACT, 0, m, &cBinop_mTRqwPe8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_5ftnPcjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DCmFQgMC, HV_BINOP_MAX, 0, m, &cBinop_DCmFQgMC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iWVu5jcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5ftnPcjG, HV_BINOP_MULTIPLY, 0, m, &cBinop_5ftnPcjG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2IH3VvMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KLhE4gnR_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pzk8qRlU, 0, m, &sTabread_pzk8qRlU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SKX5sXEn_sendMessage);
}

void Heavy_ChaffVerb::cSystem_C0QIfWSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mTRqwPe8, HV_BINOP_SUBTRACT, 1, m, &cBinop_mTRqwPe8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DE7IjjYx, 2, m, &cDelay_DE7IjjYx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_O8kxrxOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_C0QIfWSU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KLhE4gnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JHgqyc4t, 0, m, &cDelay_JHgqyc4t_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DE7IjjYx, 0, m, &cDelay_DE7IjjYx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JFYtORSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_DCmFQgMC, HV_BINOP_MAX, 1, m, &cBinop_DCmFQgMC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DCmFQgMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2IH3VvMQ, HV_BINOP_SUBTRACT, 1, m, &cBinop_2IH3VvMQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_SKX5sXEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JHgqyc4t, 0, m, &cDelay_JHgqyc4t_sendMessage);
}

void Heavy_ChaffVerb::cBinop_adVqBGys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JHgqyc4t, 2, m, &cDelay_JHgqyc4t_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mTRqwPe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_adVqBGys_sendMessage);
}

void Heavy_ChaffVerb::cCast_K6u7jCXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Sxa856Vc, 0, m, &cVar_Sxa856Vc_sendMessage);
  cMsg_GWNibYnU_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vhAZxxiF, 0, m, &cTabhead_vhAZxxiF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ab8uhK3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Ivq0vNYV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Ivq0vNYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3w4f86NM_sendMessage);
}

void Heavy_ChaffVerb::cDelay_V1quRLLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_V1quRLLa, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_avV5j0eB, 0, m, &cDelay_avV5j0eB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_V1quRLLa, 0, m, &cDelay_V1quRLLa_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YANjEak7, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_avV5j0eB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_avV5j0eB, m);
  cMsg_vXD2faP2_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_lcagQ5RP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_gm3gQDfX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_hncopPsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6Jf8awa6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_ZA2moZ9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZVnB1vY1_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_V1quRLLa, 2, m, &cDelay_V1quRLLa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VN5J0oGd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6Jf8awa6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ZA2moZ9n, 0, m, &hTable_ZA2moZ9n_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3w4f86NM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_hncopPsf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vXD2faP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ZA2moZ9n, 0, m, &hTable_ZA2moZ9n_sendMessage);
}

void Heavy_ChaffVerb::cCast_VN5J0oGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_V1quRLLa, 0, m, &cDelay_V1quRLLa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZVnB1vY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_avV5j0eB, 2, m, &cDelay_avV5j0eB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gm3gQDfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YANjEak7, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_ZdFbYQZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hlEyloRV, HV_BINOP_SUBTRACT, 0, m, &cBinop_hlEyloRV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_d9fMw8wT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XDwPBenr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_XDwPBenr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cMybJsOI_sendMessage);
}

void Heavy_ChaffVerb::cVar_dwx7zDra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NoSHdNMO_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_CwYxkmuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CwYxkmuL, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sVmIeNmm, 0, m, &cDelay_sVmIeNmm_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rWbJFMc4, 0, m, &sTabread_rWbJFMc4_sendMessage);
}

void Heavy_ChaffVerb::cDelay_sVmIeNmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sVmIeNmm, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rWbJFMc4, 0, m, &sTabread_rWbJFMc4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sVmIeNmm, 0, m, &cDelay_sVmIeNmm_sendMessage);
}

void Heavy_ChaffVerb::sTabread_rWbJFMc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Y38zgqIZ, HV_BINOP_SUBTRACT, 0, m, &cBinop_Y38zgqIZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_8ZvCB7qw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k0hDJo0H, HV_BINOP_MAX, 0, m, &cBinop_k0hDJo0H_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cMybJsOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8ZvCB7qw, HV_BINOP_MULTIPLY, 0, m, &cBinop_8ZvCB7qw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hlEyloRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3qOE0HT7_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rWbJFMc4, 0, m, &sTabread_rWbJFMc4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eP7rMKes_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hTGSm3rr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y38zgqIZ, HV_BINOP_SUBTRACT, 1, m, &cBinop_Y38zgqIZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sVmIeNmm, 2, m, &cDelay_sVmIeNmm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NoSHdNMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hTGSm3rr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3qOE0HT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CwYxkmuL, 0, m, &cDelay_CwYxkmuL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sVmIeNmm, 0, m, &cDelay_sVmIeNmm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8V0ignQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_k0hDJo0H, HV_BINOP_MAX, 1, m, &cBinop_k0hDJo0H_sendMessage);
}

void Heavy_ChaffVerb::cBinop_k0hDJo0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hlEyloRV, HV_BINOP_SUBTRACT, 1, m, &cBinop_hlEyloRV_sendMessage);
}

void Heavy_ChaffVerb::cCast_eP7rMKes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CwYxkmuL, 0, m, &cDelay_CwYxkmuL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nRh6PX8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CwYxkmuL, 2, m, &cDelay_CwYxkmuL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Y38zgqIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nRh6PX8l_sendMessage);
}

void Heavy_ChaffVerb::cCast_z1kLZGdS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dwx7zDra, 0, m, &cVar_dwx7zDra_sendMessage);
  cMsg_d9fMw8wT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ZdFbYQZi, 0, m, &cTabhead_ZdFbYQZi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UmDry9uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mK7OV9M7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_mK7OV9M7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Z9SpKXFT_sendMessage);
}

void Heavy_ChaffVerb::cDelay_mXSNy8NC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mXSNy8NC, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qQQi5lkX, 0, m, &cDelay_qQQi5lkX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mXSNy8NC, 0, m, &cDelay_mXSNy8NC_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6S4DHi75, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_qQQi5lkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qQQi5lkX, m);
  cMsg_8XxuQKU7_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_otO7fVR6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ws6gNb6K_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_0P1zyKOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rba8nAIU_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Wpgscf8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2pjObLdO_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mXSNy8NC, 2, m, &cDelay_mXSNy8NC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k8oi2SiD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rba8nAIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Wpgscf8e, 0, m, &hTable_Wpgscf8e_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Z9SpKXFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_0P1zyKOC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8XxuQKU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Wpgscf8e, 0, m, &hTable_Wpgscf8e_sendMessage);
}

void Heavy_ChaffVerb::cCast_k8oi2SiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mXSNy8NC, 0, m, &cDelay_mXSNy8NC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2pjObLdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_qQQi5lkX, 2, m, &cDelay_qQQi5lkX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ws6gNb6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6S4DHi75, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_M4YvjE3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qb7dKf6X, HV_BINOP_SUBTRACT, 0, m, &cBinop_qb7dKf6X_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AXlbHOr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wdXaMl4N_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wdXaMl4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_FmMr1Dii_sendMessage);
}

void Heavy_ChaffVerb::cVar_2gM0L0Cs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fWmP14Jv_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_f5OaB0aY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_f5OaB0aY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ILNVgBHr, 0, m, &cDelay_ILNVgBHr_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_zoLt6y3U, 0, m, &sTabread_zoLt6y3U_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ILNVgBHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ILNVgBHr, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_zoLt6y3U, 0, m, &sTabread_zoLt6y3U_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ILNVgBHr, 0, m, &cDelay_ILNVgBHr_sendMessage);
}

void Heavy_ChaffVerb::sTabread_zoLt6y3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_vlFvqLxG, HV_BINOP_SUBTRACT, 0, m, &cBinop_vlFvqLxG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_IO5iS2JY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j6GwZox3, HV_BINOP_MAX, 0, m, &cBinop_j6GwZox3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FmMr1Dii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IO5iS2JY, HV_BINOP_MULTIPLY, 0, m, &cBinop_IO5iS2JY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qb7dKf6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4KHH54DH_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_zoLt6y3U, 0, m, &sTabread_zoLt6y3U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7U4STJd0_sendMessage);
}

void Heavy_ChaffVerb::cSystem_cFCebtuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vlFvqLxG, HV_BINOP_SUBTRACT, 1, m, &cBinop_vlFvqLxG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ILNVgBHr, 2, m, &cDelay_ILNVgBHr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fWmP14Jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cFCebtuT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4KHH54DH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_f5OaB0aY, 0, m, &cDelay_f5OaB0aY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ILNVgBHr, 0, m, &cDelay_ILNVgBHr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BxjrSbq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_j6GwZox3, HV_BINOP_MAX, 1, m, &cBinop_j6GwZox3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_j6GwZox3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qb7dKf6X, HV_BINOP_SUBTRACT, 1, m, &cBinop_qb7dKf6X_sendMessage);
}

void Heavy_ChaffVerb::cCast_7U4STJd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_f5OaB0aY, 0, m, &cDelay_f5OaB0aY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nqfn0pkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_f5OaB0aY, 2, m, &cDelay_f5OaB0aY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vlFvqLxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nqfn0pkh_sendMessage);
}

void Heavy_ChaffVerb::cCast_OfpFLva9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2gM0L0Cs, 0, m, &cVar_2gM0L0Cs_sendMessage);
  cMsg_AXlbHOr3_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_M4YvjE3d, 0, m, &cTabhead_M4YvjE3d_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fPMV6PNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cdzLBLRn_sendMessage);
}

void Heavy_ChaffVerb::cSystem_cdzLBLRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_pPmHePrI_sendMessage);
}

void Heavy_ChaffVerb::cDelay_vZLKQigP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vZLKQigP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Jv9dk5d, 0, m, &cDelay_1Jv9dk5d_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vZLKQigP, 0, m, &cDelay_vZLKQigP_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_70INXAA6, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_1Jv9dk5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1Jv9dk5d, m);
  cMsg_jIvMNwSa_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_4uWynnl7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_LpRVvNGS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_ey6aBt9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tsccW4Y4_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Bc18DgJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CXm5FGul_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vZLKQigP, 2, m, &cDelay_vZLKQigP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8rrjLBRy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tsccW4Y4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Bc18DgJK, 0, m, &hTable_Bc18DgJK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pPmHePrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_ey6aBt9j_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jIvMNwSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Bc18DgJK, 0, m, &hTable_Bc18DgJK_sendMessage);
}

void Heavy_ChaffVerb::cCast_8rrjLBRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vZLKQigP, 0, m, &cDelay_vZLKQigP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CXm5FGul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Jv9dk5d, 2, m, &cDelay_1Jv9dk5d_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LpRVvNGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_70INXAA6, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_WbDquKYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xrFIWWTX, HV_BINOP_SUBTRACT, 0, m, &cBinop_xrFIWWTX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wOyDJpRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YFluwahw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_YFluwahw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DGtRWWqS_sendMessage);
}

void Heavy_ChaffVerb::cVar_GYrx9IoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XgtJStKp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_cR1RgjDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cR1RgjDh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C1nYfjfg, 0, m, &cDelay_C1nYfjfg_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_d8CU25Ny, 0, m, &sTabread_d8CU25Ny_sendMessage);
}

void Heavy_ChaffVerb::cDelay_C1nYfjfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C1nYfjfg, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_d8CU25Ny, 0, m, &sTabread_d8CU25Ny_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C1nYfjfg, 0, m, &cDelay_C1nYfjfg_sendMessage);
}

void Heavy_ChaffVerb::sTabread_d8CU25Ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_27cGLCE9, HV_BINOP_SUBTRACT, 0, m, &cBinop_27cGLCE9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_YvA25P6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PCVv96wW, HV_BINOP_MAX, 0, m, &cBinop_PCVv96wW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DGtRWWqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YvA25P6i, HV_BINOP_MULTIPLY, 0, m, &cBinop_YvA25P6i_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xrFIWWTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rrxp88Tr_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_d8CU25Ny, 0, m, &sTabread_d8CU25Ny_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y49R5OpP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_iGE9HuBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_27cGLCE9, HV_BINOP_SUBTRACT, 1, m, &cBinop_27cGLCE9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C1nYfjfg, 2, m, &cDelay_C1nYfjfg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XgtJStKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iGE9HuBh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rrxp88Tr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cR1RgjDh, 0, m, &cDelay_cR1RgjDh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C1nYfjfg, 0, m, &cDelay_C1nYfjfg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pnOwFltG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_PCVv96wW, HV_BINOP_MAX, 1, m, &cBinop_PCVv96wW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PCVv96wW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xrFIWWTX, HV_BINOP_SUBTRACT, 1, m, &cBinop_xrFIWWTX_sendMessage);
}

void Heavy_ChaffVerb::cCast_y49R5OpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cR1RgjDh, 0, m, &cDelay_cR1RgjDh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZkxZMtCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cR1RgjDh, 2, m, &cDelay_cR1RgjDh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_27cGLCE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ZkxZMtCY_sendMessage);
}

void Heavy_ChaffVerb::cCast_h4kWsSiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GYrx9IoJ, 0, m, &cVar_GYrx9IoJ_sendMessage);
  cMsg_wOyDJpRu_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_WbDquKYi, 0, m, &cTabhead_WbDquKYi_sendMessage);
}

void Heavy_ChaffVerb::cVar_k4vFkX7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zm8WJwS1, 0, m, &cVar_Zm8WJwS1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cdfSlOpK, 0, m, &cVar_cdfSlOpK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qmmf0Boh, 0, m, &cVar_qmmf0Boh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bpThspCY, 0, m, &cVar_bpThspCY_sendMessage);
}

void Heavy_ChaffVerb::cVar_m4BmPXGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_45FCAoQ5_sendMessage);
}

void Heavy_ChaffVerb::cPack_Poz53EhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_8I3Zin3n, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_cdfSlOpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vztiuzLw, HV_BINOP_MULTIPLY, 0, m, &cBinop_vztiuzLw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JUQLQxgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_it4357Rr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_it4357Rr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5O79CuXt_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_vztiuzLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_15ZXbyQ1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mtc3YiXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vztiuzLw, HV_BINOP_MULTIPLY, 1, m, &cBinop_vztiuzLw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5O79CuXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mtc3YiXw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_15ZXbyQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Dv6nL3PM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Dv6nL3PM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_iRpF2klt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fM7JrK0V, m);
}

void Heavy_ChaffVerb::cBinop_iRpF2klt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8lNzCTEj, m);
}

void Heavy_ChaffVerb::cVar_qmmf0Boh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_COhrcvnM, HV_BINOP_MULTIPLY, 0, m, &cBinop_COhrcvnM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FxHOlo3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GH3D0VzP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_GH3D0VzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NSQlhOGR_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_COhrcvnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_UxDkckJw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oDb0w1jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_COhrcvnM, HV_BINOP_MULTIPLY, 1, m, &cBinop_COhrcvnM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NSQlhOGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oDb0w1jv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UxDkckJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_pl7QlUfc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pl7QlUfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_kYQUuT4u_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xFZvKuXj, m);
}

void Heavy_ChaffVerb::cBinop_kYQUuT4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qq6oXs2O, m);
}

void Heavy_ChaffVerb::cVar_bpThspCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0shQaeDW, HV_BINOP_MULTIPLY, 0, m, &cBinop_0shQaeDW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SU99FHmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sZpjcCUV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_sZpjcCUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yAdQeHSF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_0shQaeDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_JMz3Syoh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7992qohC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0shQaeDW, HV_BINOP_MULTIPLY, 1, m, &cBinop_0shQaeDW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yAdQeHSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7992qohC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JMz3Syoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_X0XjQ9th_sendMessage);
}

void Heavy_ChaffVerb::cBinop_X0XjQ9th_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ZHbKVSxc_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lxeLbn2k, m);
}

void Heavy_ChaffVerb::cBinop_ZHbKVSxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_NTB7pA3n, m);
}

void Heavy_ChaffVerb::cBinop_dnIYyjab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_3TK88cro, 0, m, &cPack_3TK88cro_sendMessage);
}

void Heavy_ChaffVerb::cMsg_c46fFnHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_k4vFkX7E, 0, m, &cVar_k4vFkX7E_sendMessage);
}

void Heavy_ChaffVerb::cBinop_45FCAoQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Poz53EhL, 0, m, &cPack_Poz53EhL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MjrkzQ1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_3PxPpXda, 0, m, &cPack_3PxPpXda_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_bocuAlTD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_WD6pav80_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_WD6pav80_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vgZTOhCU_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_ARWqrtDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ARWqrtDt, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ARWqrtDt, 0, m, &cDelay_ARWqrtDt_sendMessage);
  cSwitchcase_SDPBmrwp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_vgZTOhCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WD6pav80_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ARWqrtDt, 0, m, &cDelay_ARWqrtDt_sendMessage);
  cSwitchcase_SDPBmrwp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_seDUrwRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_86p0GWEh_sendMessage);
}

void Heavy_ChaffVerb::cSystem_86p0GWEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_z5982rr0_sendMessage);
}

void Heavy_ChaffVerb::cVar_3rzTJMvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ltez59AZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ltez59AZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WD6pav80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ARWqrtDt, 0, m, &cDelay_ARWqrtDt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_M42j0Uuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ARWqrtDt, 2, m, &cDelay_ARWqrtDt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_z5982rr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ltez59AZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ltez59AZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ltez59AZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_M42j0Uuj_sendMessage);
}

void Heavy_ChaffVerb::cVar_PNUL1msZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_nfDQv3y4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_6Bw2LUh2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_O2A17UeU_sendMessage);
}

void Heavy_ChaffVerb::cVar_yfdCz70C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hBcwOdTO_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_jDrqFIZH, 0, m, &cIf_jDrqFIZH_sendMessage);
}

void Heavy_ChaffVerb::cUnop_Fv7tpn9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jkdJjAjM, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_jkdJjAjM_sendMessage);
}

void Heavy_ChaffVerb::cUnop_Q2qd14qz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jkdJjAjM, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_jkdJjAjM_sendMessage);
}

void Heavy_ChaffVerb::cIf_jDrqFIZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_Q2qd14qz_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_Fv7tpn9O_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_hBcwOdTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jDrqFIZH, 1, m, &cIf_jDrqFIZH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uf40F9OZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cPMa4fEw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_cPMa4fEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VLTsJLVQ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_LSiPOQYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LSiPOQYU, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bu3PgdsA, 0, m, &cDelay_bu3PgdsA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LSiPOQYU, 0, m, &cDelay_LSiPOQYU_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ILW0xCKI, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_bu3PgdsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bu3PgdsA, m);
  cMsg_81v13wKF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_iOfDcm3w_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_3HD57pF8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_UGgEybp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GKEgXNFp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_w7EEXtTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OQpzai7T_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LSiPOQYU, 2, m, &cDelay_LSiPOQYU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EdgIiOUd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GKEgXNFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_w7EEXtTy, 0, m, &hTable_w7EEXtTy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VLTsJLVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_UGgEybp1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_81v13wKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_w7EEXtTy, 0, m, &hTable_w7EEXtTy_sendMessage);
}

void Heavy_ChaffVerb::cCast_EdgIiOUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LSiPOQYU, 0, m, &cDelay_LSiPOQYU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OQpzai7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_bu3PgdsA, 2, m, &cDelay_bu3PgdsA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3HD57pF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ILW0xCKI, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_Iouf9YOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qjAY3Fhg, HV_BINOP_SUBTRACT, 0, m, &cBinop_qjAY3Fhg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WhLNZf5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XzH6KMiU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_XzH6KMiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_PgRhJGoL_sendMessage);
}

void Heavy_ChaffVerb::cVar_LnmFpeLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W3pCGHgC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_pOOv638Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pOOv638Q, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JnKXK1Ox, 0, m, &cDelay_JnKXK1Ox_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_nmBl8hTx, 0, m, &sTabread_nmBl8hTx_sendMessage);
}

void Heavy_ChaffVerb::cDelay_JnKXK1Ox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JnKXK1Ox, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_nmBl8hTx, 0, m, &sTabread_nmBl8hTx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JnKXK1Ox, 0, m, &cDelay_JnKXK1Ox_sendMessage);
}

void Heavy_ChaffVerb::sTabread_nmBl8hTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_AckfzlxZ, HV_BINOP_SUBTRACT, 0, m, &cBinop_AckfzlxZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_9o3MTh3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wBGPwcwI, HV_BINOP_MAX, 0, m, &cBinop_wBGPwcwI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PgRhJGoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9o3MTh3C, HV_BINOP_MULTIPLY, 0, m, &cBinop_9o3MTh3C_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qjAY3Fhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tcZLNEAg_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_nmBl8hTx, 0, m, &sTabread_nmBl8hTx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_23SMl5FA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_zOK90yIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AckfzlxZ, HV_BINOP_SUBTRACT, 1, m, &cBinop_AckfzlxZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JnKXK1Ox, 2, m, &cDelay_JnKXK1Ox_sendMessage);
}

void Heavy_ChaffVerb::cMsg_W3pCGHgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zOK90yIr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tcZLNEAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pOOv638Q, 0, m, &cDelay_pOOv638Q_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JnKXK1Ox, 0, m, &cDelay_JnKXK1Ox_sendMessage);
}

void Heavy_ChaffVerb::cMsg_eRAum5oo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_wBGPwcwI, HV_BINOP_MAX, 1, m, &cBinop_wBGPwcwI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wBGPwcwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qjAY3Fhg, HV_BINOP_SUBTRACT, 1, m, &cBinop_qjAY3Fhg_sendMessage);
}

void Heavy_ChaffVerb::cCast_23SMl5FA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pOOv638Q, 0, m, &cDelay_pOOv638Q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Mh5FVbzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pOOv638Q, 2, m, &cDelay_pOOv638Q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AckfzlxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Mh5FVbzs_sendMessage);
}

void Heavy_ChaffVerb::cCast_sWuVu59m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LnmFpeLp, 0, m, &cVar_LnmFpeLp_sendMessage);
  cMsg_WhLNZf5m_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Iouf9YOs, 0, m, &cTabhead_Iouf9YOs_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_z5XIlR94_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AZJPcCCi_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_AZJPcCCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UsE3tkM6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_1OrY7Jw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K1txig4u, HV_BINOP_ADD, 0, m, &cBinop_K1txig4u_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_2VunGRv1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r1lm8Sk6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_r1lm8Sk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AgCcjMwR_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_Vu7hOJp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9lnwzXw9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vrzn9hHh_sendMessage);
}

void Heavy_ChaffVerb::cVar_JEk4GWQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OApjwMR5, 0, m, &cVar_OApjwMR5_sendMessage);
}

void Heavy_ChaffVerb::cVar_OApjwMR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t8ohoFq1, HV_BINOP_ADD, 0, m, &cBinop_t8ohoFq1_sendMessage);
}

void Heavy_ChaffVerb::cVar_ElL8J4QU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jt11on4f, HV_BINOP_ADD, 0, m, &cBinop_Jt11on4f_sendMessage);
}

void Heavy_ChaffVerb::cVar_8Uyaaiu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_r4DmOdAo_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_iM2gjP27, 0, m, &cIf_iM2gjP27_sendMessage);
}

void Heavy_ChaffVerb::cUnop_fgN5hOoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jt11on4f, HV_BINOP_ADD, 1, m, &cBinop_Jt11on4f_sendMessage);
}

void Heavy_ChaffVerb::cUnop_CiOR3X4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jt11on4f, HV_BINOP_ADD, 1, m, &cBinop_Jt11on4f_sendMessage);
}

void Heavy_ChaffVerb::cIf_iM2gjP27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_CiOR3X4W_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_fgN5hOoi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_r4DmOdAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iM2gjP27, 1, m, &cIf_iM2gjP27_sendMessage);
}

void Heavy_ChaffVerb::cVar_NrtNfVkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bYg3wIxj_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_KI19z3ay, 0, m, &cIf_KI19z3ay_sendMessage);
}

void Heavy_ChaffVerb::cUnop_PZywcTOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kD9QzyPr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_oj15Xjzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kD9QzyPr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_KI19z3ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_oj15Xjzp_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_PZywcTOe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_bYg3wIxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KI19z3ay, 1, m, &cIf_KI19z3ay_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_kD9QzyPr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Z4pddmu2, 0, m, &cSlice_Z4pddmu2_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zMDUu8l5, 0, m, &cSlice_zMDUu8l5_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tu6lz3wI_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g0AtnHvn_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_Z4pddmu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_HPREgDVc, 0, m, &cVar_HPREgDVc_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_HPREgDVc, 0, m, &cVar_HPREgDVc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_zMDUu8l5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Nv31PhhK, HV_BINOP_NEQ, 1, m, &cBinop_Nv31PhhK_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_HPREgDVc, 1, m, &cVar_HPREgDVc_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Nv31PhhK, HV_BINOP_NEQ, 1, m, &cBinop_Nv31PhhK_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_HPREgDVc, 1, m, &cVar_HPREgDVc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_HPREgDVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R6hXBp3a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wEZsbeAk_sendMessage);
}

void Heavy_ChaffVerb::cIf_8KSwcUFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SOhtdIlj_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J2N9iQX1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_SOhtdIlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nv31PhhK, HV_BINOP_NEQ, 1, m, &cBinop_Nv31PhhK_sendMessage);
}

void Heavy_ChaffVerb::cCast_J2N9iQX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HPREgDVc, 0, m, &cVar_HPREgDVc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Nv31PhhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8KSwcUFn, 1, m, &cIf_8KSwcUFn_sendMessage);
}

void Heavy_ChaffVerb::cCast_g0AtnHvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8KSwcUFn, 0, m, &cIf_8KSwcUFn_sendMessage);
}

void Heavy_ChaffVerb::cCast_tu6lz3wI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nv31PhhK, HV_BINOP_NEQ, 0, m, &cBinop_Nv31PhhK_sendMessage);
}

void Heavy_ChaffVerb::cIf_ozcZi3WJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_JEk4GWQd, 0, m, &cVar_JEk4GWQd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_5GKHX0Dh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_ozcZi3WJ, 0, m, &cIf_ozcZi3WJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_BkU321J5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_ozcZi3WJ, 0, m, &cIf_ozcZi3WJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_JDFAwEG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_ozcZi3WJ, 0, m, &cIf_ozcZi3WJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_uC79O2e5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Vu7hOJp8, 0, m, &cVar_Vu7hOJp8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_nPj72o0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ElL8J4QU, 0, m, &cVar_ElL8J4QU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EUpHWQzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_5GKHX0Dh, 1, m, &cIf_5GKHX0Dh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KlS64hBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_JDFAwEG3, 1, m, &cIf_JDFAwEG3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1Eu539Ec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_5GKHX0Dh, 1, m, &cIf_5GKHX0Dh_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_BkU321J5, 1, m, &cIf_BkU321J5_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_JDFAwEG3, 1, m, &cIf_JDFAwEG3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5c88MSlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1OrY7Jw7, 0, m, &cVar_1OrY7Jw7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XxgqZNMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_5c88MSlC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AgCcjMwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Vu7hOJp8, 0, m, &cVar_Vu7hOJp8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jkdJjAjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pdEH01NG, HV_BINOP_MULTIPLY, 0, m, &cBinop_pdEH01NG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_O2A17UeU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jkdJjAjM, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_jkdJjAjM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VXOjUwu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_BkU321J5, 1, m, &cIf_BkU321J5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Jt11on4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E4IR9DRZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hfwlkKMT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ov6eoI1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FHnZSmmu, 0, m, &cVar_FHnZSmmu_sendMessage);
}

void Heavy_ChaffVerb::cCast_E4IR9DRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ov6eoI1k, HV_BINOP_ADD, 1, m, &cBinop_ov6eoI1k_sendMessage);
}

void Heavy_ChaffVerb::cCast_hfwlkKMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JEk4GWQd, 0, m, &cVar_JEk4GWQd_sendMessage);
}

void Heavy_ChaffVerb::cCast_wEZsbeAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_q0FVTB1S_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_R6hXBp3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1Eu539Ec_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_vLgW4MmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kjlaU7dR, 0, m, &cVar_kjlaU7dR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pdEH01NG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BkU321J5, 0, m, &cIf_BkU321J5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_owG3A0Lm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JDFAwEG3, 0, m, &cIf_JDFAwEG3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_n1VAK7gC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_vik8tVeL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_owG3A0Lm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nfDQv3y4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_C3zuiNu7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_C3zuiNu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_n1VAK7gC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6Bw2LUh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PNUL1msZ, 1, m, &cVar_PNUL1msZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mLlzFGAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tKrI5wgy, 0, m, &cVar_tKrI5wgy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MsKcz4LP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3rzTJMvg, 0, m, &cVar_3rzTJMvg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UsE3tkM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_JEk4GWQd, 0, m, &cVar_JEk4GWQd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_K1txig4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R100i84R, HV_BINOP_MULTIPLY, 0, m, &cBinop_R100i84R_sendMessage);
}

void Heavy_ChaffVerb::cBinop_R100i84R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uC79O2e5, 0, m, &cIf_uC79O2e5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_smHOyqhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ov6eoI1k, HV_BINOP_ADD, 0, m, &cBinop_ov6eoI1k_sendMessage);
}

void Heavy_ChaffVerb::cCast_Vrzn9hHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JEk4GWQd, 0, m, &cVar_JEk4GWQd_sendMessage);
}

void Heavy_ChaffVerb::cCast_9lnwzXw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_smHOyqhD, HV_BINOP_ADD, 1, m, &cBinop_smHOyqhD_sendMessage);
}

void Heavy_ChaffVerb::cCast_ui8EvQZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_z5XIlR94_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_eH07MxtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ozcZi3WJ, 1, m, &cIf_ozcZi3WJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_obtxSedD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R100i84R, HV_BINOP_MULTIPLY, 1, m, &cBinop_R100i84R_sendMessage);
}

void Heavy_ChaffVerb::cCast_tvZTJwSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1OrY7Jw7, 0, m, &cVar_1OrY7Jw7_sendMessage);
}

void Heavy_ChaffVerb::cCast_e7kSqYue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2VunGRv1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_se1CfxxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uC79O2e5, 1, m, &cIf_uC79O2e5_sendMessage);
}

void Heavy_ChaffVerb::cCast_FjQD1Zed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K1txig4u, HV_BINOP_ADD, 1, m, &cBinop_K1txig4u_sendMessage);
}

void Heavy_ChaffVerb::cCast_zaddWvZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1OrY7Jw7, 0, m, &cVar_1OrY7Jw7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Q0Wfoagc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_smHOyqhD, HV_BINOP_ADD, 0, m, &cBinop_smHOyqhD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_t8ohoFq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q0Wfoagc, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q0Wfoagc_sendMessage);
}

void Heavy_ChaffVerb::cCast_lrcztyX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JEk4GWQd, 0, m, &cVar_JEk4GWQd_sendMessage);
}

void Heavy_ChaffVerb::cCast_X9WBnvYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q0Wfoagc, HV_BINOP_MULTIPLY, 1, m, &cBinop_Q0Wfoagc_sendMessage);
}

void Heavy_ChaffVerb::cCast_xFhmlisr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JEk4GWQd, 0, m, &cVar_JEk4GWQd_sendMessage);
}

void Heavy_ChaffVerb::cCast_UibFka17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t8ohoFq1, HV_BINOP_ADD, 1, m, &cBinop_t8ohoFq1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_m2mHjNTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R6hXBp3a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wEZsbeAk_sendMessage);
}

void Heavy_ChaffVerb::cReceive_JAlARGNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ItU380X9_sendMessage(_c, 0, m);
  cMsg_7d6qzdSf_sendMessage(_c, 0, m);
  cMsg_s8yrEN62_sendMessage(_c, 0, m);
  cMsg_ab8uhK3V_sendMessage(_c, 0, m);
  cMsg_UmDry9uh_sendMessage(_c, 0, m);
  cMsg_fPMV6PNp_sendMessage(_c, 0, m);
  cMsg_MJih7RnF_sendMessage(_c, 0, m);
  cMsg_6d3ZrZFE_sendMessage(_c, 0, m);
  cMsg_mRpRHhWP_sendMessage(_c, 0, m);
  cMsg_NK27DJdn_sendMessage(_c, 0, m);
  cMsg_DDCxZUpa_sendMessage(_c, 0, m);
  cMsg_F9sXnCIv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Zm8WJwS1, 0, m, &cVar_Zm8WJwS1_sendMessage);
  cMsg_JUQLQxgj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cdfSlOpK, 0, m, &cVar_cdfSlOpK_sendMessage);
  cMsg_FxHOlo3R_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qmmf0Boh, 0, m, &cVar_qmmf0Boh_sendMessage);
  cMsg_SU99FHmz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bpThspCY, 0, m, &cVar_bpThspCY_sendMessage);
  cMsg_Rr2AqyTF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rmuZI1ZV, 0, m, &cVar_rmuZI1ZV_sendMessage);
  cMsg_LP5M2Wvr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tKrI5wgy, 0, m, &cVar_tKrI5wgy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JASygFtc, 0, m, &cVar_JASygFtc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kjlaU7dR, 0, m, &cVar_kjlaU7dR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E5GVivOF, 0, m, &cVar_E5GVivOF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gxFiLM5W, 0, m, &cVar_gxFiLM5W_sendMessage);
  cMsg_seDUrwRI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3rzTJMvg, 0, m, &cVar_3rzTJMvg_sendMessage);
  cMsg_uf40F9OZ_sendMessage(_c, 0, m);
  cSwitchcase_0U82drI4_onMessage(_c, NULL, 0, m, NULL);
  cMsg_UsE3tkM6_sendMessage(_c, 0, m);
  cMsg_m2mHjNTe_sendMessage(_c, 0, m);
  cMsg_AgCcjMwR_sendMessage(_c, 0, m);
  cSwitchcase_bocuAlTD_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_ZF0YUKC8, 0, m, &cVar_ZF0YUKC8_sendMessage);
  cMsg_jSokIxI5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zJAhhKy7, 0, m, &cVar_zJAhhKy7_sendMessage);
  cMsg_rGaCA7pz_sendMessage(_c, 0, m);
  cMsg_hCTW0WZP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GEcAhmZ8, 0, m, &cVar_GEcAhmZ8_sendMessage);
  cMsg_I79T9ylW_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Wnh3RMT8, 0, m, &cTabhead_Wnh3RMT8_sendMessage);
  cMsg_pOwbymw4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_AbUv6Rxa, 0, m, &cVar_AbUv6Rxa_sendMessage);
  cMsg_NWDNlvmu_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_CiaBiVUx, 0, m, &cTabhead_CiaBiVUx_sendMessage);
  cMsg_RHf8NP5K_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Zf3XSh8Q, 0, m, &cVar_Zf3XSh8Q_sendMessage);
  cMsg_Jo6SmE9X_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ZspbjrXY, 0, m, &cTabhead_ZspbjrXY_sendMessage);
  cMsg_vU76c0BS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sY1p39Y5, 0, m, &cVar_sY1p39Y5_sendMessage);
  cMsg_A7w72u7b_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_PZS2RrJp, 0, m, &cTabhead_PZS2RrJp_sendMessage);
  cMsg_hAYm6QZv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_W8TUcyVA, 0, m, &cVar_W8TUcyVA_sendMessage);
  cMsg_yMuuykJq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Y0REFUsa, 0, m, &cTabhead_Y0REFUsa_sendMessage);
  cMsg_fqwDgtwq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WY62FWJH, 0, m, &cVar_WY62FWJH_sendMessage);
  cMsg_voTo4a3X_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_VH7M8GlM, 0, m, &cTabhead_VH7M8GlM_sendMessage);
  cMsg_JFYtORSo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Sxa856Vc, 0, m, &cVar_Sxa856Vc_sendMessage);
  cMsg_GWNibYnU_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vhAZxxiF, 0, m, &cTabhead_vhAZxxiF_sendMessage);
  cMsg_8V0ignQ0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dwx7zDra, 0, m, &cVar_dwx7zDra_sendMessage);
  cMsg_d9fMw8wT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ZdFbYQZi, 0, m, &cTabhead_ZdFbYQZi_sendMessage);
  cMsg_BxjrSbq4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2gM0L0Cs, 0, m, &cVar_2gM0L0Cs_sendMessage);
  cMsg_AXlbHOr3_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_M4YvjE3d, 0, m, &cTabhead_M4YvjE3d_sendMessage);
  cMsg_pnOwFltG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GYrx9IoJ, 0, m, &cVar_GYrx9IoJ_sendMessage);
  cMsg_wOyDJpRu_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_WbDquKYi, 0, m, &cTabhead_WbDquKYi_sendMessage);
  cMsg_eRAum5oo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LnmFpeLp, 0, m, &cVar_LnmFpeLp_sendMessage);
  cMsg_WhLNZf5m_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Iouf9YOs, 0, m, &cTabhead_Iouf9YOs_sendMessage);
}

void Heavy_ChaffVerb::cReceive_MVl0p7Qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_mLlzFGAp_sendMessage);
}

void Heavy_ChaffVerb::cReceive_0Camk34R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NrtNfVkp, 0, m, &cVar_NrtNfVkp_sendMessage);
}

void Heavy_ChaffVerb::cReceive_7GP9dzfb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yfdCz70C, 0, m, &cVar_yfdCz70C_sendMessage);
}

void Heavy_ChaffVerb::cReceive_JiQS9hV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pdEH01NG, HV_BINOP_MULTIPLY, 1, m, &cBinop_pdEH01NG_sendMessage);
}

void Heavy_ChaffVerb::cReceive_iisfWxL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UibFka17_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xFhmlisr_sendMessage);
}

void Heavy_ChaffVerb::cReceive_im3mCUiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9WBnvYP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lrcztyX0_sendMessage);
}

void Heavy_ChaffVerb::cReceive_pp8qtJxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ElL8J4QU, 0, m, &cVar_ElL8J4QU_sendMessage);
}

void Heavy_ChaffVerb::cReceive_dF9KIZPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nPj72o0W_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8Uyaaiu9, 0, m, &cVar_8Uyaaiu9_sendMessage);
}

void Heavy_ChaffVerb::cReceive_83AOxpgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_MsKcz4LP_sendMessage);
}

void Heavy_ChaffVerb::cReceive_LMH1cg84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FjQD1Zed_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zaddWvZZ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_xXGKSEzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_obtxSedD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tvZTJwSO_sendMessage);
}

void Heavy_ChaffVerb::cReceive_jMzPCS1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_se1CfxxZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e7kSqYue_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ZuUSAuIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XwQcfSML, m);
}

void Heavy_ChaffVerb::cReceive_J9zWq8Hk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2pYC7S7j, m);
}

void Heavy_ChaffVerb::cReceive_eO17iq8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JASygFtc, 0, m, &cVar_JASygFtc_sendMessage);
}

void Heavy_ChaffVerb::cReceive_dildUuMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_vLgW4MmD_sendMessage);
}

void Heavy_ChaffVerb::cReceive_1DBY1Qxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AYuAIczb, 0, m, &cVar_AYuAIczb_sendMessage);
}

void Heavy_ChaffVerb::cReceive_v6CQdCe7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6aLfVu2s, 0, m, &cVar_6aLfVu2s_sendMessage);
}

void Heavy_ChaffVerb::cReceive_QkW9AqnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rmuZI1ZV, 0, m, &cVar_rmuZI1ZV_sendMessage);
}

void Heavy_ChaffVerb::cReceive_QaVRAQGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_y43jU9Rt, m);
}

void Heavy_ChaffVerb::cReceive_LsbYlL3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cmx2s5AI, m);
}

void Heavy_ChaffVerb::cReceive_pbGbXpte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9o3MTh3C, HV_BINOP_MULTIPLY, 1, m, &cBinop_9o3MTh3C_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sWuVu59m_sendMessage);
}

void Heavy_ChaffVerb::cReceive_TyP9iHWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eH07MxtC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ui8EvQZx_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_z2Fj9mVh, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_RfoYL2qg, VOf(Bf4));
    __hv_line_f(&sLine_DklJ5SDZ, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_LHbrNcNF, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_lIEZ0Mxl, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_NrzILD28, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_YVXgqNYD, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_2ytGmiKh, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_Irf27Rto, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_GpO4jdGa, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_0AyXrPkI, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_oefZTjOB, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_nGZEviOs, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_w0yStSGH, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_G7u18Yvp, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_J5ScRWwu, VIf(I0));
    __hv_varread_f(&sVarf_zb7oJVYw, VOf(Bf2));
    __hv_rpole_f(&sRPole_P7VLnXF8, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_ufL71xut, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_eSdQBy59, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_y43jU9Rt, VOf(Bf1));
    __hv_tabread_f(&sTabread_nmBl8hTx, VOf(Bf5));
    __hv_varread_f(&sVarf_cmx2s5AI, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_ILW0xCKI, VIf(Bf9));
    __hv_varread_f(&sVarf_2pYC7S7j, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_Rh6a9PBr, VOf(Bf9));
    __hv_varread_f(&sVarf_qd0gNTtK, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_iZ6khDxT, VOf(Bf2));
    __hv_rpole_f(&sRPole_Xle4sjh6, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_8I3Zin3n, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_W3z52TUg, VOf(Bf2));
    __hv_tabread_f(&sTabread_PNZNngt8, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_sWPP1lIe, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_pzk8qRlU, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_rWbJFMc4, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_d8CU25Ny, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_zoLt6y3U, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_tgbzZvny, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_0s86JQUP, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_u1ItxPrc, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_YANjEak7, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_6S4DHi75, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_70INXAA6, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_gwZ9hqgs, VOf(Bf9));
    __hv_varread_f(&sVarf_fM7JrK0V, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_8lNzCTEj, VOf(Bf3));
    __hv_rpole_f(&sRPole_5voas3A2, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_ZltNwp5A, VOf(Bf3));
    __hv_varread_f(&sVarf_xFZvKuXj, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_Qq6oXs2O, VOf(Bf12));
    __hv_rpole_f(&sRPole_ivYiGl13, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_DuDoObTu, VOf(Bf12));
    __hv_varread_f(&sVarf_lxeLbn2k, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_NTB7pA3n, VOf(Bf11));
    __hv_rpole_f(&sRPole_My8cJpRB, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_pdQH10sz, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_LXLObLxv, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_5JALhfJc, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_5ts2noJC, VIf(Bf11));
    __hv_line_f(&sLine_UOZ4ob1n, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_XwQcfSML, VOf(Bf3));
    __hv_mul_f(VIf(I0), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf11), VIf(Bf3), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf13), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
